-- Button : assumes you want to use gfxspritesheet images for the button states;
-- button touch area is the size of the up sprite

local ActionHelper = include("ActionHelper")

Button = {}

local function waitForInput( button )

	while true do
			
			local event = nil
		
			coroutine.yield({
				button.gameobject, 
				game.M_MsgGameObjectTouchEvent_GetMsgTypeId(),
				function(msg) 
					event = msg.event -- need to capture the event because we can't yield from here
					return true 
				end,
				
				button.gameobject, 
				game.M_MsgUpdate_GetMsgTypeId(),
				function(msg) 
					button.spamTicks = button.spamTicks + 1
					if (button.spamTicks > button.spamDelay) then
						if (not button.isPressEnabled) then
							--print("spamticks enabled press" .. button.spamDelay)
							button.isPressEnabled = true
						end
					end
				end
			})
			
			if event == game.TouchEvent_Down then
				--print("touch down")
				if (button.upSprite ~= nil) then
					button.upSprite:SetVisible(false)
					button.downSprite:SetVisible(true)
					
					if( button.upOverlaySprite ~= nil ) then
						button.upOverlaySprite:SetVisible(false)
						button.downOverlaySprite:SetVisible(true)
					end
				end
				button.isDown = true
			
			elseif event == game.TouchEvent_Cancel then
				--print("touch cancel")
				if (button.upSprite ~= nil) then
					button.upSprite:SetVisible(true)
					button.downSprite:SetVisible(false)
					
					if( button.upOverlaySprite ~= nil ) then
						button.upOverlaySprite:SetVisible(true)
						button.downOverlaySprite:SetVisible(false)
					end
				end
				button.isDown = false
			
			elseif button.isDown and event == game.TouchEvent_Up then
				--print("touch up")
				if (button.upSprite ~= nil) then
					button.upSprite:SetVisible(true)
					button.downSprite:SetVisible(false)
					
					if( button.upOverlaySprite ~= nil ) then
						button.upOverlaySprite:SetVisible(true)
						button.downOverlaySprite:SetVisible(false)
					end
				end
				button.isDown = false
				
				if button.onTouchUp and button.isPressEnabled then
					game.playSfx("audio/sfx/menu_click.wav")
					button.onTouchUp()
					button.isPressEnabled = false
					button.spamTicks = 0
				end
				
			end
			--print("touch general")
			
			event = nil
		end

end

Button.zone = function(layer, priority, parent, xPos, yPos, w, h, debugDraw)

	local button = {}
	
	button.layer = layer or "HUD"
	button.priority = priority or 50
	
	local obj = game.GetGameWorld():createGameObject("GameObject");
	button.gameobject = obj
	if parent then
		obj:setParent(parent)
	end
	
	local x = xPos or 0
	local y = yPos or 0
	obj:setPos(x, y)
	
	button.preventSpam = false
	button.spamTicks = 0
	button.spamDelay = 0
	button.isPressEnabled = false
	function button:setSpamDelay( delay )
		local dt = delay or 25
		button.preventSpam = true
		button.spamDelay = dt
		button.spamTicks = dt
		button.isPressEnabled = false
		--print("button spam delay = " .. dt)
	end
	
	local dbg = debugDraw or false
	if (dbg) then
		--print("dbg")
		local spr = obj:addSprite( "gfx/overlay", 0, 0, 1, 1)
		spr:SetLayerByName(button.layer)
		spr:SetPriority(priority)
		spr:setWidth(w)
		spr:setHeight(h)
		spr:center()
		
	end

	
	button.touch = obj:addTouch( w, h, priority )
	button.touch:setAnchor( w * 0.5, h * 0.5 )

	RunIndyCoroutine( waitForInput, button )
	
	return button

end


Button.new = function(sheet, name, layer, priority, parent, xPos, yPos, useDownSprite_, scale)

	local button = {}
	
	local scale = scale or 1.0
	button.scale = scale
	
	local useDownSprite = true
	if (useDownSprite_ ~= nil) then
		useDownSprite = useDownSprite_
	end
	
	button.preventSpam = false
	button.spamTicks = 0
	button.spamDelay = 0
	button.isPressEnabled = false
	function button:setSpamDelay( delay )
		--if(delay~=nil) then
			--print("button spam delay proposed = " .. delay)
		--end
		local dt = delay or 25
		--print("button spam delay = " .. dt)
		button.preventSpam = true
		button.spamDelay = dt
		button.spamTicks = dt
		button.isPressEnabled = false
		--print("button spam delay = " .. dt)
	end
	button:setSpamDelay()
	
	function button:show()
		self.upSprite:SetVisible(true)
		self.touch:setEnabled(1)
		
		if(self.downSprite) then
			self.downSprite:SetVisible(false)
		end
		
		if(self.upOverlaySprite) then
			self.upOverlaySprite:SetVisible(true)
		end
		
		if(self.downOverlaySprite) then
			self.downOverlaySprite:SetVisible(false)
		end
		
		if(self.text) then
			self.text:SetVisible(true)
		end
	end
	
	function button:hide()
		self.upSprite:SetVisible(false)
		self.touch:setEnabled(0)
		
		if(self.downSprite) then
			self.downSprite:SetVisible(false)
		end
		
		if(self.upOverlaySprite) then
			self.upOverlaySprite:SetVisible(false)
		end
		
		if(self.downOverlaySprite) then
			self.downOverlaySprite:SetVisible(false)
		end
		
		if(self.text) then
			self.text:SetVisible(false)
		end
	end
	
	function button:disable()
		self.upSprite:SetAlpha(128)
		self.touch:setEnabled(0)
		
		if(self.downSprite) then
			self.downSprite:SetAlpha(0)
		end
		
		if(self.upOverlaySprite) then
			self.upOverlaySprite:SetAlpha(0)
		end
		
		if(self.downOverlaySprite) then
			self.downOverlaySprite:SetAlpha(0)
		end
		
		if(self.text) then
			self.text:SetAlpha(0)
		end
	end
	
	function button:enable()
	
		self.upSprite:SetAlpha(255)
		self.touch:setEnabled(1)
		
		if(self.downSprite) then
			self.downSprite:SetAlpha(255)
		end
		
		if(self.upOverlaySprite) then
			self.upOverlaySprite:SetAlpha(255)
		end
		
		if(self.downOverlaySprite) then
			self.downOverlaySprite:SetAlpha(255)
		end
				
		if(self.text) then
			self.text:SetAlpha(255)
		end
	end
	
	function button:setText(text, font, scale, offsetX, offsetY)
		if self.text then
			self.gameobject:removeGfx(self.text)
		end

		local font = font or "zombie_font_description"
		local scale = scale or 0.5
		scale = scale*button.scale
		local offsetX = offsetX or 0
		local offsetY = offsetY or 0
		
		local textGfx = self.gameobject:addTextRaster(font, text, offsetX, offsetY, scale, scale)
		textGfx:SetLayerByName(self.layer)
		textGfx:center()
		textGfx:SetPriority(self.priority-1)
		self.text = textGfx
		
	end
	
	button.layer = layer or "HUD"
	button.priority = priority or 50
	
	local obj = game.GetGameWorld():createGameObject("GameObject");
	button.gameobject = obj
	if parent then
		obj:setParent(parent)
	end
	
	local x = xPos or 0
	local y = yPos or 0
	obj:setPos(x, y)
	
	function button:addOverlaySprite( sheet, name, scale, offsetX, offsetY)
		local scale = scale or 1.0
		
		--print ("overlay scale before= "..scale)
		scale = scale*button.scale
		--print ("overlay scale after= "..scale)
		
		local offsetX = offsetX or 0
		local offsetY = offsetY or 0
		
		local spr = obj:addSpriteSheet( sheet, name, offsetX, offsetY, scale, scale)
		spr:SetLayerByName(button.layer)
		spr:SetPriority(button.priority-1)
		spr:center()
		
		button.upOverlaySprite = spr
		button.upOverlaySprite:SetVisible(true)
		
		spr = obj:addSpriteSheet( sheet, name .. "_down", offsetX, offsetY, scale, scale)
		spr:SetLayerByName(button.layer)
		spr:SetPriority(button.priority-1)
		spr:center()
		
		button.downOverlaySprite = spr
		button.downOverlaySprite:SetVisible(false)
	end
	
	if (name ~= nil) and (name ~= "") then
		local spr = obj:addSpriteSheet( sheet, name, 0, 0, scale, scale )
		spr:SetLayerByName(button.layer)
		spr:SetPriority(button.priority)
		spr:center()
		
		button.upSprite = spr
		
		local n = name
		if (useDownSprite) then
			n = name .. "_down"
		end
		spr = obj:addSpriteSheet( sheet, n, 0, 0, scale, scale )
		spr:SetLayerByName(button.layer)
		spr:SetPriority(button.priority)
		spr:center()
		
		button.downSprite = spr
	else
		local spr = obj:addSprite( sheet, 0, 0 )
		spr:SetLayerByName(button.layer)
		spr:SetPriority(button.priority)
		spr:center()
		
		button.upSprite = spr
		
		spr = obj:addSprite( sheet, 0, 0 )
		spr:SetLayerByName(button.layer)
		spr:SetPriority(button.priority)
		spr:center()
		
		button.downSprite = spr
	end
	
	button.touch = obj:addTouch( button.upSprite:width()*scale, button.upSprite:height()*scale, priority )
	button.touch:setAnchor( button.upSprite:width() * scale * 0.5, button.upSprite:height() * scale * 0.5 )
	
	
	button.upSprite:SetVisible(true)
	button.downSprite:SetVisible(false)
	
	--would be nice if we could run the coroutine (lua function) on a gameobject
	--from inside lua so that when the object dies, it cleans up the coroutine
	RunIndyCoroutine( waitForInput, button )
	
	return button

end

return Button


