local venueId, inGame = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")

local ChallengerPopup = {}

local menuScale = game.menuScale()

ChallengerPopup.show = function()
	if (inGame == 1) then
		inGame = true
	else
		inGame = false
	end
	
	local challengeTitle, challengeDesc

	if( venueId == 0 ) then
		challengeTitle = game.getLocalizedText("CHALLENGER_TITLE_SF")
		challengeDesc = game.getLocalizedText("CHALLENGER_DESC_SF")
	elseif ( venueId == 1 ) then
		challengeTitle = game.getLocalizedText("CHALLENGER_TITLE_CH")
		challengeDesc = game.getLocalizedText("CHALLENGER_DESC_CH")
	elseif ( venueId == 2 ) then
		challengeTitle = game.getLocalizedText("CHALLENGER_TITLE_AT")
		challengeDesc = game.getLocalizedText("CHALLENGER_DESC_AT")
	elseif ( venueId == 3 ) then
		challengeTitle = game.getLocalizedText("CHALLENGER_TITLE_LA")
		challengeDesc = game.getLocalizedText("CHALLENGER_DESC_LA")
	elseif ( venueId == 4 ) then
		challengeTitle = game.getLocalizedText("CHALLENGER_TITLE_NY")
		challengeDesc = game.getLocalizedText("CHALLENGER_DESC_NY")
	end


	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("ChallengerPopup")
	
	if (inGame) then
		game.pauseGame()
	end
	

	local basePriority = 40
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("HUD")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)

	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "challenge_popup", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority)
	
	local challenger = obj:addSprite("gfx/menu/character/challenger_0" .. venueId, -bg:width()*0.5*menuScale+15*menuScale, 0, menuScale, menuScale)
	challenger:SetLayerByName("POPUP")
	challenger:center()
	challenger:SetPriority(basePriority-1)
	
	local buttonAccept = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, -30*menuScale, 95*menuScale, true, menuScale)
	buttonAccept.gameobject:setTag("buttonAccept")
	buttonAccept:setText( game.getLocalizedText("ACCEPT") )
	buttonAccept.onTouchUp = function()
		--ChallengerPopup.hide()
		game.startChallenge()
	end
	
	local buttonDecline = Button.new("xml_resources/sprite_menu.xml", "btn_red", "POPUP", basePriority-2, obj, 100*menuScale, 95*menuScale, true, menuScale)
	buttonDecline.gameobject:setTag("buttonDecline")
	buttonDecline:setText( game.getLocalizedText("DECLINE") )
	buttonDecline.onTouchUp = function() 
		ChallengerPopup.hide()
		if (inGame) then
			game.resumeGame()
		end
	end


	--[[local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175, -bg:height() * 0.5 + 10)
	closeButton.onTouchUp = function() 
		ChallengerPopup.hide()
	end--]]

	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), 40 )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(0)

	local textObj = game.GetGameWorld():createGameObject("GameObject");
	textObj:setTag("ChallengerPopupText")
		
	local info = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(challengeTitle), 0, -110*menuScale, 0.6*menuScale, 0.6*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
	info:SetLayerByName("POPUP")
	info:center()
	info:SetPriority(basePriority-2)
	
	local upgrade = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(challengeDesc), 40*menuScale, -70*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Left, 270*menuScale, true )
	upgrade:SetLayerByName("POPUP")
	upgrade:center()
	upgrade:SetPriority(basePriority-2)
	
	textObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	textObj:setAlpha(0.0)
	
	obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	obj:setScale(0.0, 1.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)

	action = textObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	touch:setEnabled(1)
	
end

ChallengerPopup.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("ChallengerPopup")
	local textObj = game.GetGameWorld():getObjectByTag("ChallengerPopupText")
	local fadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG")
	if obj then
		local action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		if fadedBGObj then
			game.GetGameWorld():destroyGameObject(fadedBGObj)
		end
	
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(obj)
	end

end

ChallengerPopup.show()