local timeLeft, hasPowerUp = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")

local menuScale = game.menuScale()

local FatigueMeterInfo = {}
FatigueMeterInfo.timeLeft = timeLeft
FatigueMeterInfo.timeGfx = nil
FatigueMeterInfo.resume = false
FatigueMeterInfo.buttonUsePowerUp = nil
FatigueMeterInfo.buttonRejuvenate = nil

local function updateTimer()
	coroutine.yield({
			game.engineReceiver(), 
			game.M_MsgUpdate_GetMsgTypeId(),
			function(msg) 
				local timerObj = game.GetGameWorld():getObjectByTag("FatigueMeterTimerText")
				
				if( timerObj ) then
					local nextTime = math.floor(FatigueMeterInfo.timeLeft)
					FatigueMeterInfo.timeLeft = FatigueMeterInfo.timeLeft - msg.time
					
					--update the timer text
					if( FatigueMeterInfo.timeLeft <= nextTime ) then
						local hours = math.floor(FatigueMeterInfo.timeLeft/3600)
						local minutes = math.floor(math.fmod(FatigueMeterInfo.timeLeft,3600)/60)
						local seconds = math.floor(math.fmod(math.fmod(FatigueMeterInfo.timeLeft,3600),60))
						local timeLefttext = game.getLocalizedText("FATIGUE_TIMER")
						timeLefttext = select( 1, timeLefttext:gsub("XXX", hours) )
						timeLefttext = select( 1, timeLefttext:gsub("YYY", minutes) )
						timeLefttext = select( 1, timeLefttext:gsub("ZZZ", seconds) )
						
						FatigueMeterInfo.timeGfx:changeText(timeLefttext)
					end
				end
				return true
			end
		})
end

-- Get the new regen time and either close the window or refresh the menu
FatigueMeterInfo.updateFatigueTimer = function()
	FatigueMeterInfo.timeLeft = game.getFatigueTime()
	
	if( FatigueMeterInfo.timeLeft <= 0 ) then
		FatigueMeterInfo.resume = true
		FatigueMeterInfo.hide()
	else
		FatigueMeterInfo.refresh()
	end
end


-- Calculate and display the regen time and buttons to rejuvenate the player's energy
FatigueMeterInfo.show = function()

	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("FatigueMeterInfo")

	local basePriority = 40

	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setParent(rootObj)
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG_p")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_medium", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, -bg:height()*menuScale * 0.5 + 10*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		FatigueMeterInfo.resume = true
		FatigueMeterInfo.hide()
	end

	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)

	local timerObj = game.GetGameWorld():createGameObject("GameObject");
	timerObj:setTag("FatigueMeterTimerText")
	
	-- Convert the timeLeft to hrs, mins and secs
	if( FatigueMeterInfo.timeLeft > 0 ) then
		local hours = math.floor(timeLeft/3600)
		local minutes = math.floor(math.fmod(timeLeft,3600)/60)
		local seconds = math.fmod(math.fmod(timeLeft,3600),60)
		local timeLefttext = game.getLocalizedText("FATIGUE_TIMER")
		timeLefttext = select( 1, timeLefttext:gsub("XXX", hours) )
		timeLefttext = select( 1, timeLefttext:gsub("YYY", minutes) )
		timeLefttext = select( 1, timeLefttext:gsub("ZZZ", seconds) )

		local textGfx = timerObj:addTextRaster("zombie_font_description", game.getLocalizedText("TIMER_MESSAGE"), 10*menuScale, -35*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
		textGfx:SetLayerByName("POPUP")
		textGfx:center()
		textGfx:SetPriority(basePriority-2)
		
		local timeGfx = timerObj:addTextRaster("zombie_font_description", timeLefttext, 10*menuScale, -10*menuScale, 0.6*menuScale, 0.6*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
		timeGfx:SetLayerByName("POPUP")
		timeGfx:center()
		timeGfx:SetPriority(basePriority-2)
		timeGfx:SetColorProper( 204, 255, 255, 255 )
		
		FatigueMeterInfo.timeGfx = timeGfx

		-- create buttons to rejuvenate the player
		if( hasPowerUp == 1 ) then
		
			--option to use power up or rejevunate 
			local buttonHotTub = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, -60*menuScale, 25*menuScale, true, menuScale)
			buttonHotTub.gameobject:setTag("buttonHotTub")
			buttonHotTub:setText( game.getLocalizedText("USE_POWERUP") )
			buttonHotTub.onTouchUp = function()
				hasPowerUp = game.useFatiguePowerUp()
				FatigueMeterInfo.updateFatigueTimer()
			end
			FatigueMeterInfo.buttonUsePowerUp = buttonHotTub
			
			local buttonPurchase = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, 60*menuScale, 25*menuScale, true, menuScale)
			buttonPurchase.gameobject:setTag("buttonPurchase")
			buttonPurchase:setText( game.getLocalizedText("FATIGUE_REJUVENATE") )
			buttonPurchase.onTouchUp = function()
				FatigueMeterInfo.hide()
				game.showRejuvenatePrompt()
			end
			
			FatigueMeterInfo.buttonRejuvenate = buttonPurchase
		else
			local buttonPurchase = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, 0, 25*menuScale, true, menuScale)
			buttonPurchase.gameobject:setTag("buttonPurchase")
			buttonPurchase:setText( game.getLocalizedText("FATIGUE_REJUVENATE") )
			buttonPurchase.onTouchUp = function()
				FatigueMeterInfo.hide()
				game.showRejuvenatePrompt()
			end
		end
	else
		-- Plyaer is already at full energy
		local txtGfx = timerObj:addTextRaster("zombie_font_description", game.getLocalizedText("FULL_ENERGY"), 0, 0, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
		txtGfx:SetLayerByName("POPUP")
		txtGfx:center()
		txtGfx:SetPriority(basePriority-2)
	end
	
	-- animate
	timerObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	timerObj:setAlpha(0.0)
	
	obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	obj:setScale(0.0, 1.0)
	
	local action = obj:moveScale( 1.0, 0, 0.7, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)

	action = timerObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
end

-- Animations to close the menu
FatigueMeterInfo.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("FatigueMeterInfo")
	local textObj = game.GetGameWorld():getObjectByTag("FatigueMeterTimerText")
	local FadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG_p")
	if obj then
		--[[local action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
	
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)]]
		
		FatigueMeterInfo.timeLeft = 0
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(FadedBGObj)
		game.GetGameWorld():destroyGameObject(obj)
	end
	
	if( FatigueMeterInfo.resume == true) then
		game.resumeGame()
	end
end

-- Refreshes the menu
FatigueMeterInfo.refresh = function()
	local obj = game.GetGameWorld():getObjectByTag("FatigueMeterInfo")
	local timerObj = game.GetGameWorld():getObjectByTag("FatigueMeterTimerText")
	if obj then
		local action = timerObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
	
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		if( hasPowerUp == 0 ) then
			FatigueMeterInfo.buttonUsePowerUp:hide()
			FatigueMeterInfo.buttonRejuvenate.gameobject:setPos(0, FatigueMeterInfo.buttonRejuvenate.gameobject:y())
		end
		
		
		timerObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
		timerObj:setAlpha(0.0)
		
		obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
		obj:setScale(0.0, 1.0)
		
		local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
		action:start()
		ActionHelper.waitForAction(action)

		action = timerObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
		action:start()
		ActionHelper.waitForAction(action)
				
	end
end

FatigueMeterInfo.show()
game.pauseGame()
--Update Fatigue Regen Timer
while FatigueMeterInfo.timeLeft > 0 do
updateTimer()
end