local minigameId = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")
local HelpScreen = include("HelpScreen")

local MinigamePopup = {}

local menuScale = game.menuScale()
local totalCoinObj
local totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
local totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()

local function waitForMessage()
	coroutine.yield({
		game.gameReceiver(), 
		game.M_MsgUpdateStoreCurrency_GetMsgTypeId(),
		function(msg)
			print("updating currency")
			totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
			totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()
			MinigamePopup.totalCoinGfx:changeText(""..totalNumOfCoins)
			MinigamePopup.totalPlatinumGfx:changeText(""..totalNumofPlatinum)
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillCoroutine_GetMsgTypeId(),
		function(msg)
			local ROUTINE = "MinigamePopup"
			if (msg.menu == ROUTINE) then
				print("Killing "..ROUTINE.." Routine...")
				return true
			end
		end
	})
end

MinigamePopup.playMinigame = function()
	local helpId = "minigame_" .. minigameId
	if (game.isTutorialOn() or not game.tutorialComplete(helpId)) then
		HelpScreen.show(helpId)
		HelpScreen.onClose = function()
			game.setTutorialComplete(helpId)
			game.loadMinigame(minigameId)
		end
	else
		game.loadMinigame(minigameId)
	end
end

MinigamePopup.show = function()
	--All the generic stuff
	local basePriority = 40

	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("MinigamePopup")
	
	local textObj = game.GetGameWorld():createGameObject("GameObject");
	textObj:setTag("MinigamePopupText")
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), 40 )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)
	
	local mainButton = Button.zone("POPUP", basePriority-1, obj, 0, 0, lua_sys.screenWidth(), lua_sys.screenHeight())
	mainButton.onTouchUp = function() 
		MinigamePopup.hide()
	end

	--Customized stuff for different popups
	local minigameData = game.getMinigameInfo(minigameId)
	
	local titleText = minigameData.name_
	local infoText = minigameData.description_
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_large", 0 ,0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)
	
	local premium = false
	local price = minigameData.goldValue_
	if (minigameData.platinumValue_ > 0) then
		premium = true
		price = minigameData.platinumValue_
	end
	
	if (not minigameData.unlocked_) then --NEEDS TO BE BOUGHT
		local icon = "coin_gold"
		if (premium) then
			icon = "coin_platinum"
		end
		
		local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", icon, 50*menuScale, 54*menuScale, menuScale, menuScale)
		moneyIcon:SetLayerByName("POPUP")
		moneyIcon:SetPriority(basePriority-4)
		moneyIcon:center()

		local buttonPurchase = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, 95*menuScale, 55*menuScale, true, menuScale)
		buttonPurchase.gameobject:setTag("buttonPurchase")
		buttonPurchase:setText( price )
		buttonPurchase.onTouchUp = function()
			if ( game.purchaseMinigame(minigameData.id_) ) then
				game.playSfx("audio/sfx/cash_register.wav")
				MinigamePopup.hide()
				MinigamePopup.playMinigame()
			else
				print("Not enough currency to buy!")
				game.showNoMoneyPrompt()
			end
		end
		
		totalCoinObj = game.GetGameWorld():createGameObject("GameObject")
		totalCoinObj:setTag("totalCoinObj")
		totalCoinObj:setParent(obj)
		
		-- total coin obj
		local totalCoinGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "basic_currency_gold_coin_b", 0, 0, 0.7*menuScale, 0.7 *menuScale)
		totalCoinGfx_icon:SetLayerByName("POPUP")
		totalCoinGfx_icon:SetPriority(basePriority-2)
		totalCoinGfx_icon:center()

		-- current total coins
		text = totalNumOfCoins
		totalCoinGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 25*menuScale, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalCoinGfx:SetLayerByName("POPUP")
		totalCoinGfx:SetPriority(basePriority-2)
		totalCoinGfx:left_center()
		MinigamePopup.totalCoinGfx = totalCoinGfx
		
		-- platinum gfx
		local totalPlatinumGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "premium_currency_platinum_coin", 150*menuScale, 0, 0.7*menuScale, 0.7*menuScale )
		totalPlatinumGfx_icon:SetLayerByName("POPUP")
		totalPlatinumGfx_icon:SetPriority(basePriority-2)
		totalPlatinumGfx_icon:center()
		
		-- current platinum coins
		text = totalNumofPlatinum
		totalPlatinumGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 175*menuScale, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalPlatinumGfx:SetLayerByName("POPUP")
		totalPlatinumGfx:SetPriority(basePriority-2)
		totalPlatinumGfx:left_center()
		MinigamePopup.totalPlatinumGfx = totalPlatinumGfx
		
		totalCoinObj:setPos( -game.windowSizeX()*0.5 + 30*menuScale, game.windowSizeY()*0.5 - 30*menuScale)
	else --ALREADY BOUGHT

		local buttonPlay = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-3, obj, 95*menuScale, 55*menuScale, true, menuScale)
		buttonPlay.gameobject:setTag("buttonPlay")
		buttonPlay:setText( game.getLocalizedText("PLAY") )
		buttonPlay.onTouchUp = function()
			MinigamePopup.hide()
			if( minigameData.timeLeft_ > 0 ) then
				game.showSkipWaitTimePrompt(minigameId)
			else
				MinigamePopup.playMinigame()
			end
		end

	end

	
	local title = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(titleText), 0, -bg:height()*menuScale/2, 0.8*menuScale, 0.8*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
	title:SetLayerByName("POPUP")
	title:center()
	title:SetPriority(basePriority-2)

	local description = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(infoText), 95*menuScale, -55*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Left, 150*menuScale, true )
	description:SetLayerByName("POPUP")
	description:center()
	description:SetPriority(basePriority-2)

	local icon = obj:addSprite(minigameData.pictureSprite_, (-bg:width()*menuScale/2)+100*menuScale, 5*menuScale, menuScale, menuScale)
	icon:SetLayerByName("POPUP")
	icon:center()
	icon:SetPriority(basePriority-2)
	
	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, -bg:height()*menuScale * 0.5 + 3*menuScale)
	closeButton.onTouchUp = function() 
		MinigamePopup.hide()
	end
	
	if (totalCoinObj) then
		totalCoinObj:setAlpha(0.0)
	end
	
	--Animate in
	textObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	textObj:setAlpha(0.0)
	
	obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	obj:setScale(0.0, 1.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)

	action = textObj:moveAlpha( 1.0, 0.45, lua_sys.Quadratic_EASEOUT )
	action:start()
	
	if (totalCoinObj) then
		local action2 = totalCoinObj:moveAlpha( 1.0, 0.45, lua_sys.Back_EASEOUT )
		action2:start()
	end
	
	ActionHelper.waitForAction(action)
	
	touch:setEnabled(1)
	
	waitForMessage()
end

MinigamePopup.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("MinigamePopup")
	local textObj = game.GetGameWorld():getObjectByTag("MinigamePopupText")
	local fadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG")
	local timerObj = game.GetGameWorld():getObjectByTag("MinigameTimeLeft")
	if obj then
		local action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		if (totalCoinObj) then
			local action2 = totalCoinObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
			action2:start()
		end
		ActionHelper.waitForAction(action)
		
		if fadedBGObj then
			game.GetGameWorld():destroyGameObject(fadedBGObj)
		end
	
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		MinigamePopup.timeLeft = 0
		if( timerObj ) then
			game.GetGameWorld():destroyGameObject(timerObj)
		end
		
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(obj)
	end

	game.killCoroutine("MinigamePopup")
end

MinigamePopup.show()