local minigameId, resultText, barFillPct = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")
local ProgressBar = include("ProgressBar")

local MinigameResultsMenu = {}

local menuScale = game.menuScale()

local obj, bgObj
local coinObj, platinumObj, totalCoinObj
local scoreObj, statTextObj
local buttonObj

local action, action2, action3

local lastButton = nil

MinigameResultsMenu.show = function()
	local basePriority = 100
	
	obj = game.GetGameWorld():createGameObject("GameObject")
	obj:setTag("MinigameResultsMenu")
	
	action = obj:wait( 1 )
	action:start()
	ActionHelper.waitForAction(action)
	
	bgObj = game.GetGameWorld():createGameObject("GameObject")
	bgObj:setTag("bgObj")
	bgObj:setParent(obj)
	
	statTextObj = game.GetGameWorld():createGameObject("GameObject")
	statTextObj:setTag("statTextObj")
	statTextObj:setParent(bgObj)
	statTextObj:setPos(7*menuScale, 48*menuScale)
	
	buttonObj = game.GetGameWorld():createGameObject("GameObject")
	buttonObj:setTag("buttonObj")
	buttonObj:setParent(obj)
	 	 
	coinObj = game.GetGameWorld():createGameObject("GameObject")
	coinObj:setTag("coinObj")
	coinObj:setParent(obj)
	
	platinumObj = game.GetGameWorld():createGameObject("GameObject")
	platinumObj:setTag("platinumObj")
	platinumObj:setParent(obj)
	
	totalCoinObj = game.GetGameWorld():createGameObject("GameObject")
	totalCoinObj:setTag("totalCoinObj")
	totalCoinObj:setParent(obj)
	
	scoreObj = game.GetGameWorld():createGameObject("GameObject")
	scoreObj:setTag("scoreObj")
	scoreObj:setParent(obj)

	--Create buttons
	
	local spacing = 55*menuScale
	local startY = -25*menuScale
	
	--Replay
	local buttonReplay = Button.new("xml_resources/sprite_menu.xml", "tab_blue", "POPUP", basePriority-2, buttonObj, 0, startY + spacing * 0, true, menuScale)
	buttonReplay.gameobject:setTag("buttonAccept")
	buttonReplay:setText( game.getLocalizedText("REPLAY"), nil, 0.4, 0, 15*menuScale  )
	buttonReplay:addOverlaySprite( "xml_resources/sprite_menu.xml", "btn_replay", 1, 1*menuScale, -10*menuScale  )
	buttonReplay.onTouchUp = function()
		local minigameData = game.getMinigameInfo(minigameId)
		if( minigameData.timeLeft_ > 0 ) then
			game.showSkipWaitTimePrompt(minigameId)
		else
			game.loadMinigame(minigameId)
		end
	end
	
	--Venue Menu
	local buttonMainMenu = Button.new("xml_resources/sprite_menu.xml", "tab_blue", "POPUP", basePriority-2, buttonObj, 0, startY + spacing * 1, true, menuScale)
	buttonMainMenu.gameobject:setTag("buttonAccept")
	buttonMainMenu:setText( game.getLocalizedText("TRAINING"), nil, 0.4, 0, 15*menuScale  )
	buttonMainMenu:addOverlaySprite( "xml_resources/sprite_menu.xml", "btn_home_small", 1, 1*menuScale, -10*menuScale  )
	buttonMainMenu.onTouchUp = function()
		MinigameResultsMenu.hide()
		game.quitGame("minigame_select")
	end
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local touch = bgObj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(0)
	
	
	buttonObj:setPos( game.windowSizeX()+70*menuScale, game.windowSizeY()*0.5)
	
	-- bg
	local bgGfx = bgObj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_large", 0, 0, menuScale, menuScale)
	bgGfx:SetLayerByName("POPUP")
	bgGfx:SetPriority(basePriority-1)
	bgGfx:center()
	
	bgObj:setPos( game.windowSizeX()*0.4, -bgGfx:height()*menuScale )
		
	-- results text
	local text = game.getLocalizedText("RESULTS")
	local titleGfx = bgObj:addTextRaster( game.getMidSizeFont(), text, 0, -bgGfx:height()*0.5*menuScale+10*menuScale, 1*menuScale, 1*menuScale, game.GfxText_Format_Center )
	titleGfx:SetLayerByName("POPUP")
	titleGfx:SetPriority(basePriority-2)
	titleGfx:center()
	
	text = resultText
	--[[
	text = ""
	text = text .. "Score: " .. 12345 .. "\n"
	text = text .. "Highest Multiplier: " .. "x5" .. "\n"
	text = text .. "Progress: "--]]
	
	local padding = 10*menuScale
	local resultText = bgObj:addTextRaster( "zombie_font_description", text, padding, -10*menuScale, 0.6*menuScale, 0.6*menuScale, game.GfxText_Format_Center, bgGfx:width()*menuScale-(padding*2) )
	resultText:SetLayerByName("POPUP")
	resultText:SetPriority(basePriority-2)
	resultText:center()
	resultText:setLineSpacing(1.3)
	
	local barBase = ""
	local barFill = ""
	local statVal = 0
	local statName = ""
	if (minigameId == 1) then
		barBase = "gfx/minigames/common/contact_base"
		barFill = "gfx/minigames/common/contact_fill"
		statName = "Contact"
		statVal = game.playerTotalContact()
	elseif (minigameId == 2) then
		barBase = "gfx/minigames/common/vision_base"
		barFill = "gfx/minigames/common/vision_fill"
		statName = "Vision"
		statVal = game.playerTotalVision()
	elseif (minigameId == 3) then
		barBase = "gfx/minigames/common/power_base"
		barFill = "gfx/minigames/common/power_fill"
		statName = "Power"
		statVal = game.playerTotalPower()
	end
	
	local statBar = ProgressBar.new(barBase, barFill, "POPUP", basePriority-2, bgObj, 7*menuScale, 25*menuScale)

	if (barFillPct >= 100 and statVal <= 50) then
		text = statName .. ": " .. (statVal-1)
	else
		text = statName .. ": " .. (statVal)
	end
	
	local statText = statTextObj:addTextRaster( "zombie_font_description", text, 0, 0, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, bgGfx:width()*menuScale-(padding*2) )
	statText:SetLayerByName("POPUP")
	statText:SetPriority(basePriority-5)
	statText:center()
	
	-- bring the bg down
	game.playSfx("audio/sfx/woosh2.wav")
	action = bgObj:movePosition( 0, game.windowSizeY()*0.5+bgGfx:height()*menuScale, 0.5, lua_sys.Back_EASEOUT )
	
	action:start()

	ActionHelper.waitForAction(action)
	
	statBar:setPercent(barFillPct/100)
	
	if (barFillPct >= 100 and statVal <= 50) then
		game.playSfx("audio/sfx/gain_level.wav")
		text = statName .. ": " .. (statVal)
		statText:changeText(text)
		statTextObj:setScale(1.4, 1.4)
		action = statTextObj:moveScale( -0.4, -0.4, 0.2, lua_sys.Quadratic_EASEOUT )
		action:start()
		ActionHelper.waitForAction(action)
		statBar:setPercent(0)
		
		if( game.showPlayerStatsTutorial() ) then
			game.showPopupStatInfo()
			game.disablePlayerStatsTutorial()
		end
	end
	
	game.playSfx("audio/sfx/woosh2.wav")
	action3 = buttonObj:movePosition( -(50+70)*menuScale, 0, 0.5, lua_sys.Quadratic_EASEINOUT )
	action3:start()
	ActionHelper.waitForAction(action3)
	
	touch:setEnabled(1)
end

MinigameResultsMenu.hide = function()
	local obj = game.GetGameWorld():getObjectByTag("MinigameResultsMenu")
	--local staticObjLayer = game.GetGameWorld():getObjectByTag("StaticObjLayer")
	
	if obj then
		game.playSfx("audio/sfx/woosh1.wav")
		action = obj:movePosition( lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		print("Destroy Gameove Menu")
		game.GetGameWorld():destroyGameObject(obj)		
	else
		print("Where'd options go?")
	end
	
	
end

MinigameResultsMenu.show()
