local platinum, gold = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")

local menuScale = game.menuScale()

local NoGoldMoneyPrompt = {}
NoGoldMoneyPrompt.resume = false --whether to resume game when menu is closed

local obj = game.GetGameWorld():createGameObject("GameObject");
obj:setTag("NoGoldMoneyPrompt")
obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
obj:setScale(0.0, 1.0)

local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
fadedBGObj:setTag("FadedBG_nomoney")

local textObj = game.GetGameWorld():createGameObject("GameObject");
textObj:setTag("NoGoldMoneyPromptText")
textObj:setParent(obj)

	
-- create the menu
NoGoldMoneyPrompt.show = function()

	local basePriority = 30
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local scale = 1.5
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_medium", 0, 0, 1*menuScale, 1.25*menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, -bg:height() * scale * 0.5 *menuScale + 20*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		NoGoldMoneyPrompt.hide()
	end

	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)
	
	local mainButton = Button.zone("POPUP", basePriority-1, obj, 0, 0, lua_sys.screenWidth(), lua_sys.screenHeight())
	mainButton.onTouchUp = function() 
		NoGoldMoneyPrompt.hide()
	end

	-- Message
	local text = game.getLocalizedText("NOT_ENOUGH_GOLD_MONEY")
	text = select( 1, text:gsub("XXX", platinum) )
	text = select( 1, text:gsub("YYY", gold) )
	
	local textGfx = textObj:addTextRaster("zombie_font_description", text, 0, -35*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 335*menuScale, true )
	textGfx:SetLayerByName("POPUP")
	textGfx:center()
	textGfx:SetPriority(basePriority-2)
	
	local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_platinum", -45*menuScale, 43*menuScale, menuScale, menuScale)
	moneyIcon:SetLayerByName("POPUP")
	moneyIcon:SetPriority(basePriority-4)
	moneyIcon:center()

	-- yes/no buttons
		
	local buttonOK = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, 0*menuScale, 43*menuScale, true, menuScale)
	buttonOK.gameobject:setTag("buttonOK")
	buttonOK:setText( platinum )
	buttonOK.onTouchUp = function()
		--NoGoldMoneyPrompt.hide()
		if ( game.convertPlatinumToGold(platinum, gold) ) then			
			game.playSfx("audio/sfx/cash_register.wav");
			NoGoldMoneyPrompt.hide()
		else
			print("Not enough currency to buy!")
			NoGoldMoneyPrompt.hide()
			local inStore = 1
			game.showNoMoneyPrompt(inStore)			
		end
	end
	
	--actions
	textObj:setAlpha(0.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	action = textObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
end

-- close the menu
NoGoldMoneyPrompt.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("NoGoldMoneyPrompt")
	local textObj = game.GetGameWorld():getObjectByTag("NoGoldMoneyPromptText")
	local FadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG_nomoney")
	if obj then

		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(FadedBGObj)
		game.GetGameWorld():destroyGameObject(obj)
	end
	
	if( NoGoldMoneyPrompt.resume == true) then
		game.resumeGame()
	end
end

NoGoldMoneyPrompt.show()
