--local rootObj = ...
local venueId, inGame = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")
local Objective = include("Objectives")
local SwipeComponent = include("SwipeComponent")
local HelpScreen = include("HelpScreen")

local ObjectiveSummary = {}

local menuScale = game.menuScale()

ObjectiveSummary.show = function()
	

	local basePriority = 45
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("HUD")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
		
	local touch = fadedBGObj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)
	
	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("ObjectiveSummary")
	
	local offsetX = 0
	local offsetY = -lua_sys.screenHeight()*0.5+70*menuScale
	local spacingY = 60*menuScale
	ObjectiveSummary.totalListHeight = 0
	
	--[[local text = game.getLocalizedText("Objectives")

	local gfx = obj:addTextRaster( game.getMidSizeFont(), text, 0, -lua_sys.screenHeight()*0.5+25, 0.5, 0.5 )
	gfx:SetLayerByName("HUD")
	gfx:SetPriority(basePriority-5)
	gfx:center()]]
	
	local missionControl = game.getMissionControl()	
	
	local numMissions = 0
	if (inGame == 0) then
		numMissions = missionControl:totalMissions(venueId)-1
	else
		numMissions = missionControl:totalMissions(venueId)-1--missionControl:totalActiveMissions(venueId)-1
	end
	
	local hasAMainObjective = false
	
	for i = 0, numMissions, 1 do
		local mission = missionControl:getMissionById(i, venueId)
		
		local name = game.getLocalizedText(mission:getDescription())
		name = select( 1, name:gsub("XXX", mission:getTargetOccurrences()) )
		name = select( 1, name:gsub("YYY", mission:getEndTarget()) )
		
		local desc = game.getLocalizedText(mission:getDescription())
		desc = select( 1, desc:gsub("XXX", mission:getTargetOccurrences()) )
		desc = select( 1, desc:gsub("YYY", mission:getEndTarget()) )
		
		local rewardType = mission:getRewardType()
		local rewardValue = mission:getRewardValue()
		local isComplete = mission:completed()
		local isMainObjective =  mission:isMainObjective()
		local isFailed = mission:failed()
		
		if (isMainObjective) then
			hasAMainObjective = true
			
			if (i == 0) then
				local moText = game.getLocalizedText("MAIN_OBJECTIVES_TITLE")
				moText = select( 1, moText:gsub("XXX", missionControl:totalMissionsCompleted(venueId, true)) )
				moText = select( 1, moText:gsub("YYY", 5) )
				local name = game.getLocalizedText(mission:getDescription())
				local mainObjectiveTxt = obj:addTextRaster("zombie_font_description", moText, 0, offsetY-40*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Center, 335*menuScale, true )
				mainObjectiveTxt:SetLayerByName("HUD")
				mainObjectiveTxt:center()
				mainObjectiveTxt:SetPriority(basePriority-2)
			end
		end
		
		local progressText = game.getLocalizedText("OBJECTIVE_PROGRESS")
		progressText = select( 1, progressText:gsub("XXX", mission:getCurrentOccurrences()) )
		progressText = select( 1, progressText:gsub("YYY", mission:getTargetOccurrences()) )
		--local progressText = "Progress: " .. mission:getCurrentOccurrences() .. "/" .. mission:getTargetOccurrences()
		if (inGame == 0) then
			progressText = game.getLocalizedText("OBJECTIVE_PROGRESS_EMPTY")
		end
		if (isComplete) then
			progressText = game.getLocalizedText("OBJECTIVE_COMPLETE")
		elseif (mission:failed() == true) then
			progressText = game.getLocalizedText("OBJECTIVE_FAILED")
		end
		
		if (not isMainObjective and hasAMainObjective) then
			offsetY = offsetY + (35)
			hasAMainObjective = false
			
			local boText = game.getLocalizedText("BONUS_OBJECTIVES_TITLE")
			boText = select( 1, boText:gsub("XXX", missionControl:totalMissionsCompleted(venueId)) )
			boText = select( 1, boText:gsub("YYY", 10) )
				
			local bonusObjectivesTxt = obj:addTextRaster("zombie_font_description", boText, 0, offsetY-40*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Center, 335*menuScale, true )
			bonusObjectivesTxt:SetLayerByName("HUD")
			bonusObjectivesTxt:center()
			bonusObjectivesTxt:SetPriority(basePriority-2)
		end
		
		local pos = 1
		local objective = Objective.new( name, desc, rewardType, rewardValue, progressText, isComplete, isMainObjective, isFailed, inGame, "HUD", basePriority-2, obj, offsetX, offsetY)
		objective.onTouchUp = function()
			--print "touch up leaderboarditem"
		end

		offsetY = offsetY + spacingY
		pos = pos + 1
		ObjectiveSummary.totalListHeight = ObjectiveSummary.totalListHeight + objective.height + (spacingY - objective.height)
		--print ("function totalListHeight"..ObjectiveSummary.totalListHeight)

	end

	local extraPadding = 150
	ObjectiveSummary.totalListHeight = ObjectiveSummary.totalListHeight + extraPadding
	local swipeComponentHeight = lua_sys.screenHeight() * math.ceil(ObjectiveSummary.totalListHeight/lua_sys.screenHeight())
	--print ("swipeComponentHeight = "..swipeComponentHeight)
	if( swipeComponentHeight < lua_sys.screenHeight() ) then
		--print ("swipeComponentHeight must be at least the height of the screen")
		swipeComponentHeight = lua_sys.screenHeight()
	end
	local swipeComp = SwipeComponent.new( lua_sys.screenWidth()-70*menuScale, swipeComponentHeight, "HUD", basePriority-1, obj ) 

	local upperLimit = (lua_sys.screenHeight() * 0.5) - (ObjectiveSummary.totalListHeight - 340*menuScale)
	--print( "upperLimit"..upperLimit )
	if( upperLimit > lua_sys.screenHeight() * 0.5 ) then
		upperLimit = lua_sys.screenHeight() * 0.5
	end	
		
	swipeComp:setUpperLimit (upperLimit)
	ObjectiveSummary.swipeLayer = swipeComp;

	local staticObjLayer = game.GetGameWorld():createGameObject("GameObject");
	staticObjLayer:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	staticObjLayer:setTag("StaticObjLayer")

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "HUD", basePriority-10, staticObjLayer, -lua_sys.screenWidth()*0.5 + 20*menuScale, -lua_sys.screenHeight()*0.5+20*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		ObjectiveSummary.playBall = false
		ObjectiveSummary.hide()
	end
	
	
	if (inGame ~= 1) then
		
		-- refresh powerup list
		game.refreshPowerupList()
		
		local powerups = game.getPlayerItems(6)
		local continueButton = Button.new("xml_resources/sprite_menu.xml", "btn_green", "HUD", basePriority-10, staticObjLayer, lua_sys.screenWidth()*0.5 - 60*menuScale, lua_sys.screenHeight()*0.5-30*menuScale, true, menuScale)
		continueButton.gameobject:setTag("ContinueButton")
		
		if( powerups:size() > 0 ) then
			continueButton:setText("Continue")
		else
			continueButton:setText("Play Ball")
		end
		continueButton.onTouchUp = function() 
			if( powerups:size() > 0 ) then
				ObjectiveSummary.showPowerUpSummary = true
			else
				ObjectiveSummary.playBall = true
			end	
			ObjectiveSummary.hide()
			
		end
	
	end
	
	local gradientObj = game.GetGameWorld():createGameObject("GameObject");
	gradientObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	gradientObj:setTag("gradientObj")
	
	local gradient = gradientObj:addSprite("gfx/menu/common/fade_gradient", -lua_sys.screenWidth()*0.5, lua_sys.screenHeight()*0.5 - 75*menuScale)
	gradient:SetLayerByName("HUD")
	gradient:setWidth(lua_sys.screenWidth())
	gradient:setHeight(85*menuScale)
	gradient:SetPriority(basePriority-9)
	gradient:setVAnchor(game.Gfx_VA_ALIGN_TOP)
	gradient:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	obj:setPos( -lua_sys.screenWidth(), lua_sys.screenHeight() * 0.5 )
	staticObjLayer:setPos( -lua_sys.screenWidth(), lua_sys.screenHeight() * 0.5 )
	
	local action = obj:movePosition( lua_sys.screenWidth() * 0.5 - obj:x(), 0, 1, lua_sys.Back_EASEOUT )
	action:start()
	local action2 = staticObjLayer:movePosition( lua_sys.screenWidth() * 0.5 - staticObjLayer:x(), 0, 1, lua_sys.Back_EASEOUT )
	action2:start()
	ActionHelper.waitForAction(action)

end

ObjectiveSummary.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("ObjectiveSummary")
	local fadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG")
	local staticObjLayer = game.GetGameWorld():getObjectByTag("StaticObjLayer")
	local gradientObj = game.GetGameWorld():getObjectByTag("gradientObj")
	
	
		
	if obj then
		print ("listheight"..ObjectiveSummary.totalListHeight)
		if( ObjectiveSummary.totalListHeight > 0 ) then
			SwipeComponent.destroy()
		end
		
		
		

		
		if( ObjectiveSummary.showPowerUpSummary == true ) then
			game.showPowerUpSummary()
			animate = false
		elseif( ObjectiveSummary.playBall == true ) then
		
			local action = obj:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
			action:start()
			local action2 = staticObjLayer:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
			action2:start()
			ActionHelper.waitForAction(action)
			
			local helpId = "main_01"
			if (game.isTutorialOn() or not game.tutorialComplete(helpId)) then
				HelpScreen.show(helpId)
				HelpScreen.onClose = function()
					game.setTutorialComplete(helpId)
					game.startBusterBash()
				end
			else
				game.startBusterBash()
			end
		else 
			local action = obj:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
			action:start()
			local action2 = staticObjLayer:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
			action2:start()
			ActionHelper.waitForAction(action)
			
			if( inGame == 0 ) then
				game.clearMissions()
			end
		end
		

		if fadedBGObj then
			game.GetGameWorld():destroyGameObject(fadedBGObj)
		end
		
		if staticObjLayer  then
			game.GetGameWorld():destroyGameObject(staticObjLayer)
		end
				
		if gradientObj then
			game.GetGameWorld():destroyGameObject(gradientObj)
		end
		
		game.GetGameWorld():destroyGameObject(obj)
		
		
	else
		print("Where'd options go?")
	end

end

ObjectiveSummary.show()