local inGame, restartLevel = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")
local PowerUpItem = include("PowerUpItem")
local SwipeComponent = include("SwipeComponent")
local HelpScreen = include("HelpScreen")

local PowerUpSummary = {}

local powerupList = {}

local menuScale = game.menuScale() 

local function waitForMessage()
	-- pull this out so it doesn't get rebuilt every time this is called
	coroutine.yield({
		game.gameReceiver(), 
		game.M_MsgPlayerTogglePowerup_GetMsgTypeId(),
		function(msg)
			print "got toggle msg"
			if( msg.isClover == true ) then
				PowerUpSummary.updateToggle(msg.itemId)
			end
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillCoroutine_GetMsgTypeId(),
		function(msg)
			local ROUTINE = "PowerupSummary"
			if (msg.menu == ROUTINE) then
				print("Killing "..ROUTINE.." Routine...")
				return true
			end
		end
	})
end	

PowerUpSummary.updateToggle = function( itemId )
	for i = 1, #powerupList, 1 do
		if( powerupList[i].data.id_ ~= itemId and powerupList[i].data.rareItems_ > 0) then
			powerupList[i].updateToggle(false)
		end
		--game.togglePowerUp(powerupList[i], true)
	end
end

PowerUpSummary.show = function()
	

	local basePriority = 45
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("HUD")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local touch = fadedBGObj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)
	
	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("PowerUpSummary")
	
	local offsetX = 0
	local offsetY = -lua_sys.screenHeight()*0.5+80*menuScale
	local spacingY = 60*menuScale
	PowerUpSummary.totalListHeight = 0
	
	local text = ""
	if (inGame == 1) then
		text = game.getLocalizedText("ACTIVE_POWER_UPS")
	else
		text = game.getLocalizedText("POWER_UPS")
	end

	local gfx = obj:addTextRaster( game.getMidSizeFont(), text, 0, -lua_sys.screenHeight()*0.5+20*menuScale, 0.6*menuScale, 0.6*menuScale )
	gfx:SetLayerByName("HUD")
	gfx:SetPriority(basePriority-1)
	gfx:center()
	
	
	local powerupCat = 6
	
	-- removes any used powerups
	if( inGame == 0 ) then
		game.refreshPowerupList()
	end
	
	local items = game.getPlayerItems(powerupCat, inGame)
	
	for i = 0, items:size()-1, 1 do
		local item = items[i];
		
		if (inGame == 0 and item.id_ >= 0) or (inGame == 1 and item.activated_) then
			local pos = 1
			print("Restart Level"..restartLevel)
			local powerupitem = PowerUpItem.new( item, "HUD", basePriority-2, obj, offsetX, offsetY, inGame, restartLevel)
			
			powerupitem.data = item
			print( "item: "..item.id_ )
			table.insert(powerupList, powerupitem)
			
			offsetY = offsetY + spacingY
			pos = pos + 1
			PowerUpSummary.totalListHeight = PowerUpSummary.totalListHeight + powerupitem.height + (spacingY - powerupitem.height)
		end
		--print ("function totalListHeight = "..PowerUpSummary.totalListHeight)
	end
	
	local extraPadding = 150
	PowerUpSummary.totalListHeight = PowerUpSummary.totalListHeight + extraPadding
	print ("function addLeaderboardItem 3: "..PowerUpSummary.totalListHeight)
	
	local swipeComponentHeight = lua_sys.screenHeight() * math.ceil(PowerUpSummary.totalListHeight/lua_sys.screenHeight())
	print ("swipeComponentHeight = "..swipeComponentHeight)
	if( swipeComponentHeight < lua_sys.screenHeight() ) then
		print ("swipeComponentHeight must be at least the height of the screen")
		swipeComponentHeight = lua_sys.screenHeight()
	end
	local swipeComp = SwipeComponent.new( lua_sys.screenWidth()-70*menuScale, swipeComponentHeight, "HUD", basePriority-1, obj ) 

	local upperLimit = (lua_sys.screenHeight() * 0.5) - (PowerUpSummary.totalListHeight - 340*menuScale)
	print( "upperLimit"..upperLimit )
	if( upperLimit > lua_sys.screenHeight() * 0.5 ) then
		upperLimit = lua_sys.screenHeight() * 0.5
	end	
		
	swipeComp:setUpperLimit (upperLimit)
	PowerUpSummary.swipeLayer = swipeComp;

	local staticObjLayer = game.GetGameWorld():createGameObject("GameObject");
	staticObjLayer:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	staticObjLayer:setTag("StaticObjLayer")

	if( restartLevel == 0 ) then
		local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "HUD", basePriority-10, staticObjLayer, -lua_sys.screenWidth()*0.5 + 20*menuScale, -lua_sys.screenHeight()*0.5+20*menuScale, menuScale, menuScale)
		closeButton.onTouchUp = function() 
			PowerUpSummary.playBall = false
			PowerUpSummary.hide()
		end
	end
	
	
	if (inGame ~= 1) then
	
		local continueButton = Button.new("xml_resources/sprite_menu.xml", "btn_green", "HUD", basePriority-10, staticObjLayer, lua_sys.screenWidth()*0.5 - 60*menuScale, lua_sys.screenHeight()*0.5-30*menuScale, menuScale, menuScale)
		continueButton.gameobject:setTag("ContinueButton")
		continueButton:setText("Play Ball")
		continueButton.onTouchUp = function() 
			PowerUpSummary.playBall = true
			PowerUpSummary.hide()
		end
	
	end
	
	local gradientObj = game.GetGameWorld():createGameObject("GameObject");
	gradientObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	gradientObj:setTag("gradientObj")
	
	local gradient = gradientObj:addSprite("gfx/menu/common/fade_gradient", -lua_sys.screenWidth()*0.5, lua_sys.screenHeight()*0.5 - 75*menuScale)
	gradient:SetLayerByName("HUD")
	gradient:setWidth(lua_sys.screenWidth())
	gradient:setHeight(85*menuScale)
	gradient:SetPriority(basePriority-9)
	gradient:setVAnchor(game.Gfx_VA_ALIGN_TOP)
	gradient:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	obj:setPos( -lua_sys.screenWidth(), lua_sys.screenHeight() * 0.5 )
	staticObjLayer:setPos( -lua_sys.screenWidth(), lua_sys.screenHeight() * 0.5 )
	
	local action = obj:movePosition( lua_sys.screenWidth() * 0.5 - obj:x(), 0, 1, lua_sys.Back_EASEOUT )
	action:start()
	local action2 = staticObjLayer:movePosition( lua_sys.screenWidth() * 0.5 - staticObjLayer:x(), 0, 1, lua_sys.Back_EASEOUT )
	action2:start()
	ActionHelper.waitForAction(action)

end

PowerUpSummary.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("PowerUpSummary")
	local fadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG")
	local staticObjLayer = game.GetGameWorld():getObjectByTag("StaticObjLayer")
	local gradientObj = game.GetGameWorld():getObjectByTag("gradientObj")
	
	
		
	if obj then
		local action = obj:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
		action:start()
		local action2 = staticObjLayer:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
		action2:start()
		ActionHelper.waitForAction(action)
		game.GetGameWorld():destroyGameObject(obj)
		
		print ("listheight"..PowerUpSummary.totalListHeight)
		--if( PowerUpSummary.totalListHeight > 0 ) then
			SwipeComponent.destroy()
		--end
		
		if fadedBGObj then
			game.GetGameWorld():destroyGameObject(fadedBGObj)
		end
		
		if staticObjLayer  then
			game.GetGameWorld():destroyGameObject(staticObjLayer)
		end
		
		if gradientObj then
			game.GetGameWorld():destroyGameObject(gradientObj)
		end
		
		if( PowerUpSummary.playBall == true ) then
			local helpId = "main_01"
			if (game.isTutorialOn() or not game.tutorialComplete(helpId)) then
				HelpScreen.show(helpId)
				HelpScreen.onClose = function()
					game.setTutorialComplete(helpId)
					if( restartLevel == 0 ) then
						game.startBusterBash()
					else
						game.restartGame()
					end
				end
			else
				if( restartLevel == 0 ) then
					game.startBusterBash()
				else
					game.restartGame()
				end
			end
			
		end
		
		
	else
		print("Where'd options go?")
	end
	
	game.killCoroutine("PowerupSummary")

end


--[[return PowerUpSummary]]
PowerUpSummary.show()
waitForMessage()