local menuToLoad, inGame, restartLevel = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")

local menuScale = game.menuScale()

local QuitGamePrompt = {}
QuitGamePrompt.resume = false --whether to resume game when menu is closed

local obj = game.GetGameWorld():createGameObject("GameObject");
obj:setTag("QuitGamePrompt")
obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
obj:setScale(0.0, 1.0)

local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
fadedBGObj:setTag("FadedBG_p")

local textObj = game.GetGameWorld():createGameObject("GameObject");
textObj:setTag("QuitGamePromptText")
textObj:setParent(obj)

	
-- create the menu
QuitGamePrompt.show = function()

	local basePriority = 30
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_medium", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)

	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)

	-- Message
	local quitGameText = game.getLocalizedText("QUIT_GAME")
	if( inGame == 1 ) then
		quitGameText = game.getLocalizedText("QUIT_MAIN_GAME")
	end
	
	local textGfx = textObj:addTextRaster("zombie_font_description", quitGameText, 0, -35*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
	textGfx:SetLayerByName("POPUP")
	textGfx:center()
	textGfx:SetPriority(basePriority-2)

	-- yes/no buttons
	local buttonYes = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, -60*menuScale, 25*menuScale, true, menuScale)
	buttonYes.gameobject:setTag("buttonYes")
	buttonYes:setText( game.getLocalizedText("MAIN_YES") )
	buttonYes.onTouchUp = function()
		QuitGamePrompt.hide()
		if( inGame == 1 and restartLevel == 1 ) then
			-- refresh powerup list
			game.refreshPowerupList()
			
			local powerups = game.getPlayerItems(6)
			if( powerups:size() > 0 ) then
				game.showPowerUpSummary(false, true)
			else
				game.restartGame()
			end
		else
			game.quitGame(menuToLoad)
		end
	end
	
	local buttonNo = Button.new("xml_resources/sprite_menu.xml", "btn_red", "POPUP", basePriority-2, obj, 60*menuScale, 25*menuScale, true, menuScale)
	buttonNo.gameobject:setTag("buttonNo")
	buttonNo:setText( game.getLocalizedText("MAIN_NO") )
	buttonNo.onTouchUp = function()
		QuitGamePrompt.hide()
	end
	
	--actions
	textObj:setAlpha(0.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)

	action = textObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	touch:setEnabled(1)
end

-- close the menu
QuitGamePrompt.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("QuitGamePrompt")
	local textObj = game.GetGameWorld():getObjectByTag("QuitGamePromptText")
	local FadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG_p")
	if obj then
		local action = FadedBGObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		
		action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		
		ActionHelper.waitForAction(action)
				
		action = obj:wait(0.5)
		action:start()
		ActionHelper.waitForAction(action)
		
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(FadedBGObj)
		game.GetGameWorld():destroyGameObject(obj)
		
		game.killStoreRoutine()	
	end
	
	if( QuitGamePrompt.resume == true) then
		game.resumeGame()
	end
end

QuitGamePrompt.show()
