local cost = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")

local menuScale = game.menuScale()
local RejuvenatePrompt = {}
RejuvenatePrompt.resume = false --whether to resume game when menu is closed

local totalCoinObj
local totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
local totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()

local function waitForMessage()
	coroutine.yield({
		game.gameReceiver(), 
		game.M_MsgUpdateStoreCurrency_GetMsgTypeId(),
		function(msg)
			print("updating currency")
			totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
			totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()
			RejuvenatePrompt.totalCoinGfx:changeText(""..totalNumOfCoins)
			RejuvenatePrompt.totalPlatinumGfx:changeText(""..totalNumofPlatinum)
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillCoroutine_GetMsgTypeId(),
		function(msg)
			local ROUTINE = "RejuvenatePrompt"
			if (msg.menu == ROUTINE) then
				print("Killing "..ROUTINE.." Routine...")
				return true
			end
		end
	})
end

-- create the menu
RejuvenatePrompt.show = function()

	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("RejuvenatePrompt")

	local basePriority = 50

	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setParent(rootObj)
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_medium", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, -bg:height()*menuScale * 0.5 + 10*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		RejuvenatePrompt.hide()
		game.showFatigueInfo()
	end

	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)

	-- Display the rejuvenate message using either Buster or Samanatha's name
	local textObj = game.GetGameWorld():createGameObject("GameObject");
	textObj:setTag("RejuvenatePromptText")
	
	local msgText = game.getLocalizedText("REJUVENATE_MESSAGE")
	msgText = select( 1, msgText:gsub("XXX", cost) )
	
	if( game.getSelectedCharacter() == 0 ) then
		msgText = select( 1, msgText:gsub("YYY", game.getLocalizedText("PLAYER_BUSTER")) )	
	else
		msgText = select( 1, msgText:gsub("YYY", game.getLocalizedText("PLAYER_SAMANTHA")) )	
	end
	
	local textGfx = textObj:addTextRaster("zombie_font_description", msgText, 0, -20*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 340*menuScale, true )
	textGfx:SetLayerByName("POPUP")
	textGfx:center()
	textGfx:SetPriority(basePriority-2)

	-- yes/no buttons
	local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_platinum", -105*menuScale, 24*menuScale, menuScale, menuScale)
	moneyIcon:SetLayerByName("POPUP")
	moneyIcon:SetPriority(basePriority-3)
	moneyIcon:center()
	
	local buttonHotTub = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, -60*menuScale, 25*menuScale, menuScale, menuScale)
	buttonHotTub.gameobject:setTag("buttonHotTub")
	buttonHotTub:setText( game.getLocalizedText("MAIN_YES") )
	buttonHotTub.onTouchUp = function()
		if ( game.rejuvenatePlayer(cost) ) then
			game.playSfx("audio/sfx/cash_register.wav")
			RejuvenatePrompt.resume = true
			RejuvenatePrompt.hide()
		else
			print("Not enough currency to buy!")
			game.showNoMoneyPrompt()
		end
	end
	
	local buttonPurchase = Button.new("xml_resources/sprite_menu.xml", "btn_red", "POPUP", basePriority-2, obj, 60*menuScale, 25*menuScale, menuScale, menuScale)
	buttonPurchase.gameobject:setTag("buttonPurchase")
	buttonPurchase:setText( game.getLocalizedText("MAIN_NO") )
	buttonPurchase.onTouchUp = function()
		RejuvenatePrompt.hide()
		game.showFatigueInfo()
	end
	
	--actions
	textObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	textObj:setAlpha(0.0)
	
	obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	obj:setScale(0.0, 1.0)
	
		totalCoinObj = game.GetGameWorld():createGameObject("GameObject")
		totalCoinObj:setTag("totalCoinObj")
		totalCoinObj:setParent(obj)
		
		-- total coin obj
		local totalCoinGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "basic_currency_gold_coin_b", 0, 0, 0.7*menuScale, 0.7*menuScale )
		totalCoinGfx_icon:SetLayerByName("POPUP")
		totalCoinGfx_icon:SetPriority(basePriority-2)
		totalCoinGfx_icon:center()

		-- current total coins
		text = totalNumOfCoins
		totalCoinGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 25*menuScale, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalCoinGfx:SetLayerByName("POPUP")
		totalCoinGfx:SetPriority(basePriority-2)
		totalCoinGfx:left_center()
		RejuvenatePrompt.totalCoinGfx = totalCoinGfx
		
		-- platinum gfx
		local totalPlatinumGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "premium_currency_platinum_coin", 150*menuScale, 0, 0.7*menuScale, 0.7*menuScale )
		totalPlatinumGfx_icon:SetLayerByName("POPUP")
		totalPlatinumGfx_icon:SetPriority(basePriority-2)
		totalPlatinumGfx_icon:center()
		
		-- current platinum coins
		text = totalNumofPlatinum
		totalPlatinumGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 175*menuScale, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalPlatinumGfx:SetLayerByName("POPUP")
		totalPlatinumGfx:SetPriority(basePriority-2)
		totalPlatinumGfx:left_center()
		RejuvenatePrompt.totalPlatinumGfx = totalPlatinumGfx
		
		totalCoinObj:setPos( -game.windowSizeX()*0.5 + 30*menuScale, game.windowSizeY()*0.5 - 30*menuScale)
	
	totalCoinObj:setAlpha(0.0)
	
	local action = obj:moveScale( 1.0, 0, 0.7, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	local action2 = totalCoinObj:moveAlpha( 1.0, 0.45, lua_sys.Back_EASEOUT )
	action2:start()

	action = textObj:moveAlpha( 1.0, 0.45, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	
	
	waitForMessage()
end

-- close the menu
RejuvenatePrompt.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("RejuvenatePrompt")
	local textObj = game.GetGameWorld():getObjectByTag("RejuvenatePromptText")
	local FadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG")
	if obj then
		--[[local action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		local action2 = totalCoinObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action2:start()
		ActionHelper.waitForAction(action)
	
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)]]
		
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(FadedBGObj)
		game.GetGameWorld():destroyGameObject(obj)
	end
	
	if( RejuvenatePrompt.resume == true) then
		game.resumeGame()
	end
	
	game.killCoroutine("RejuvenatePrompt")
end

RejuvenatePrompt.show()
