local id, timeLeft, cost = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")
local HelpScreen = include("HelpScreen")

local SkipWaitTimePrompt = {}

local menuScale = game.menuScale()

local totalCoinObj
local totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
local totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()

local obj = game.GetGameWorld():createGameObject("GameObject");
obj:setTag("SkipWaitTimePrompt")
obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
obj:setScale(0.0, 1.0)

local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
fadedBGObj:setTag("FadedBG_p")

local timerObj = game.GetGameWorld():createGameObject("GameObject");
timerObj:setTag("MinigameTimeLeft")
timerObj:setParent(obj)

local function updateTimer()
	coroutine.yield({
			game.engineReceiver(), 
			game.M_MsgUpdate_GetMsgTypeId(),
			function(msg) 
				local timerObj = game.GetGameWorld():getObjectByTag("MinigameTimeLeft")
				
				if( timerObj ) then
					local nextTime = math.floor(SkipWaitTimePrompt.timeLeft)
					SkipWaitTimePrompt.timeLeft = SkipWaitTimePrompt.timeLeft - msg.time
					
					--update the timer text
					if( SkipWaitTimePrompt.timeLeft <= nextTime ) then
						local hours = math.floor(SkipWaitTimePrompt.timeLeft/3600)
						local minutes = math.floor(math.fmod(SkipWaitTimePrompt.timeLeft,3600)/60)
						local seconds = math.floor(math.fmod(math.fmod(SkipWaitTimePrompt.timeLeft,3600),60))
						local timeLefttext = game.getLocalizedText("FATIGUE_TIMER")
						timeLefttext = select( 1, timeLefttext:gsub("XXX", hours) )
						timeLefttext = select( 1, timeLefttext:gsub("YYY", minutes) )
						timeLefttext = select( 1, timeLefttext:gsub("ZZZ", seconds) )
						
						SkipWaitTimePrompt.timeGfx:changeText(timeLefttext)
					end
				end
				return true
			end,
			
			game.gameReceiver(), 
			game.M_MsgUpdateStoreCurrency_GetMsgTypeId(),
			function(msg)
				print("updating currency")
				totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
				totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()
				SkipWaitTimePrompt.totalCoinGfx:changeText(""..totalNumOfCoins)
				SkipWaitTimePrompt.totalPlatinumGfx:changeText(""..totalNumofPlatinum)
			end,
			
			game.gameReceiver(), 
			game.M_MsgKillCoroutine_GetMsgTypeId(),
			function(msg)
				local ROUTINE = "SkipWaitTimePrompt"
				if (msg.menu == ROUTINE) then
					print("Killing "..ROUTINE.." Routine...")
					return true
				end
			end
		})
end

-- create the menu
SkipWaitTimePrompt.show = function()

	local basePriority = 40

	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_large", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, -bg:height()*menuScale * 0.5 + 10*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		SkipWaitTimePrompt.hide()
	end
	
	if ( timeLeft > 0 ) then
		SkipWaitTimePrompt.timeLeft = timeLeft
	
		-- Convert the timeLeft to hrs, mins and secs
		local hours = math.floor(SkipWaitTimePrompt.timeLeft/3600)
		local minutes = math.floor(math.fmod(SkipWaitTimePrompt.timeLeft,3600)/60)
		local seconds = math.fmod(math.fmod(SkipWaitTimePrompt.timeLeft,3600),60)
		local timeLefttext = game.getLocalizedText("FATIGUE_TIMER")
		timeLefttext = select( 1, timeLefttext:gsub("XXX", hours) )
		timeLefttext = select( 1, timeLefttext:gsub("YYY", minutes) )
		timeLefttext = select( 1, timeLefttext:gsub("ZZZ", seconds) )

		local textGfx = timerObj:addTextRaster("zombie_font_description", game.getLocalizedText("MINIGAME_TIME_LEFT"), 0, -60*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
		textGfx:SetLayerByName("POPUP")
		textGfx:center()
		textGfx:SetPriority(basePriority-2)
		
		local timeGfx = timerObj:addTextRaster("zombie_font_description", timeLefttext, 0, -35*menuScale, 0.6*menuScale, 0.6*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
		timeGfx:SetLayerByName("POPUP")
		timeGfx:center()
		timeGfx:SetPriority(basePriority-2)
		timeGfx:SetColorProper( 204, 255, 255, 255 )
		
		SkipWaitTimePrompt.timeGfx = timeGfx
		
		totalCoinObj = game.GetGameWorld():createGameObject("GameObject")
		totalCoinObj:setTag("totalCoinObj")
		totalCoinObj:setParent(obj)
		
		-- total coin obj
		local totalCoinGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "basic_currency_gold_coin_b", 0, 0, 0.7*menuScale, 0.7*menuScale )
		totalCoinGfx_icon:SetLayerByName("POPUP")
		totalCoinGfx_icon:SetPriority(basePriority-2)
		totalCoinGfx_icon:center()

		-- current total coins
		text = totalNumOfCoins
		totalCoinGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 25*menuScale, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalCoinGfx:SetLayerByName("POPUP")
		totalCoinGfx:SetPriority(basePriority-2)
		totalCoinGfx:left_center()
		SkipWaitTimePrompt.totalCoinGfx = totalCoinGfx
		
		-- platinum gfx
		local totalPlatinumGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "premium_currency_platinum_coin", 150*menuScale, 0, 0.7*menuScale, 0.7 *menuScale)
		totalPlatinumGfx_icon:SetLayerByName("POPUP")
		totalPlatinumGfx_icon:SetPriority(basePriority-2)
		totalPlatinumGfx_icon:center()
		
		-- current platinum coins
		text = totalNumofPlatinum
		totalPlatinumGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 175*menuScale, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalPlatinumGfx:SetLayerByName("POPUP")
		totalPlatinumGfx:SetPriority(basePriority-2)
		totalPlatinumGfx:left_center()
		SkipWaitTimePrompt.totalPlatinumGfx = totalPlatinumGfx
		
		totalCoinObj:setPos( -game.windowSizeX()*0.5 + 30*menuScale, game.windowSizeY()*0.5 - 30*menuScale)
	end

	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)

	-- Display the rejuvenate message using either Buster or Samanatha's name
	local msgText = game.getLocalizedText("MINIGAME_SKIP")
	msgText = select( 1, msgText:gsub("XXX", cost) )
	
	local textGfx = timerObj:addTextRaster("zombie_font_description", msgText, 0, 0, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
	textGfx:SetLayerByName("POPUP")
	textGfx:center()
	textGfx:SetPriority(basePriority-2)

	-- yes/no buttons
	local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_platinum", -105*menuScale, 44*menuScale, menuScale, menuScale)
	moneyIcon:SetLayerByName("POPUP")
	moneyIcon:SetPriority(basePriority-3)
	moneyIcon:center()
	
	local buttonYes = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, -60*menuScale, 45*menuScale, true, menuScale)
	buttonYes.gameobject:setTag("buttonYes")
	buttonYes:setText( game.getLocalizedText("MAIN_YES") )
	buttonYes.onTouchUp = function()
		if( game.skipWaitTime(id, cost) ) then
			SkipWaitTimePrompt.hide()
			local helpId = "minigame_" .. id
			if (game.isTutorialOn() or not game.tutorialComplete(helpId)) then
				HelpScreen.show(helpId)
				HelpScreen.onClose = function()
					game.setTutorialComplete(helpId)
					game.loadMinigame(id)
				end
			else
				game.loadMinigame(id)
			end
		else
			print("not enough money")
			--SkipWaitTimePrompt.hide()
			game.showNoMoneyPrompt()
		end
		--SkipWaitTimePrompt.hide()
	end
	
	local buttonNo = Button.new("xml_resources/sprite_menu.xml", "btn_red", "POPUP", basePriority-2, obj, 60*menuScale, 45*menuScale, true, menuScale)
	buttonNo.gameobject:setTag("buttonNo")
	buttonNo:setText( game.getLocalizedText("MAIN_NO") )
	buttonNo.onTouchUp = function()
		SkipWaitTimePrompt.hide()
	end
	
	--actions
	totalCoinObj:setAlpha(0.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	local action2 = totalCoinObj:moveAlpha( 1.0, 0.45, lua_sys.Back_EASEOUT )
	action2:start()

end

-- close the menu
SkipWaitTimePrompt.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("SkipWaitTimePrompt")
	local FadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG_p")
	local timerObj = game.GetGameWorld():getObjectByTag("MinigameTimeLeft")
	if obj then
		local action2 = totalCoinObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action2:start()
		ActionHelper.waitForAction(action2)
		
		action = obj:moveScale( -1, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		obj:setPos(-lua_sys.screenWidth()*2,0)
		
		SkipWaitTimePrompt.timeLeft = 0
		if( timerObj ) then
			game.GetGameWorld():destroyGameObject(timerObj)
		end
		
		game.GetGameWorld():destroyGameObject(FadedBGObj)
		game.GetGameWorld():destroyGameObject(obj)
	end
	
	game.killCoroutine("SkipWaitTimePrompt")
end

SkipWaitTimePrompt.show()
while SkipWaitTimePrompt.timeLeft > 0 do
updateTimer()
end