local Button = include("Button")
local StorePurchasePopup = include("StorePurchasePopup")
local ConvertPlatinumPopup = include("ConvertPlatinumPopup")
local ActionHelper = include("ActionHelper")

local menuScale = game.menuScale()

StoreItem = {}

ItemCategory = {
	["HAT"] = 0,
	["GLOVE"] = 1,
	["BAT"] = 2,
	["SHIRT"] = 3,
	["PANTS"] = 4,
	["SHOES"] = 5,
	["POWERUP"] = 6,
	["CURRENCY"] = 7
}

StoreItem.waitForMessage = function()
	-- pull this out so it doesn't get rebuilt every time this is called
	coroutine.yield({		
		game.gameReceiver(), 
		game.M_MsgPlayerPurchaseItem_GetMsgTypeId(),
		function(msg)
			print("purchased something")
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillStoreRoutine_GetMsgTypeId(),
		function(msg)
			print "Killing..."
			return true
		end
	})
end

StoreItem.new = function( data, layer, priority, parent, xPos, yPos )
	local id = data.id_
	local category = data.category_
	local name = game.getLocalizedText(data.name_)
	local image = data.iconSpriteName_
	local sheet = data.iconSpriteSheetFile_
	local group = data.itemGroupName_
	local price = 0
	local bonusString = ""
	local hasBonus = false
	local premium = false
	local limit = data.limit_
	
	local locked = false

	if( image == "" ) then
		image = data.spriteName_
		sheet = data.spriteSheetFile_
	end
	
	if (data.goldValue_ <= 0) then
		price = data.platinumValue_
		premium = true
	else
		price = data.goldValue_
	end
	
	
	local item = {}

	item.id = id
	item.category = category
	
	local isIAP = (item.category == ItemCategory["CURRENCY"])
	
	locked = game.itemLocked(category, (id))
	if (game.getPlayerItemIsOwned(category, (id)) or (isIAP) or 
		(item.category == ItemCategory["POWERUP"]) or 
		(item.category == ItemCategory["CURRENCY"]) or 
		(premium) ) then
		locked = false
	end
	
	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("StoreItem")
	item.gameobject = obj
	
	local lockObj = game.GetGameWorld():createGameObject("GameObject");
	lockObj:setTag("lockObj")
	lockObj:setParent(obj)
	item.lockobj = lockObj
	
	--[[action = obj:wait(0.02)
	action:start()
	ActionHelper.waitForAction(action)]]
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_store.xml", "item_card", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("HUD")
	--bg:center()
	bg:SetPriority(priority)
	
	item.bgSprite = bg
	
	local bgOverlay = lockObj:addSpriteSheet("xml_resources/sprite_store.xml", "item_card_locked", 0 ,0, menuScale, menuScale)
	bgOverlay:SetLayerByName("HUD")
	bgOverlay:SetPriority(priority-4)
	bgOverlay:SetAlpha(255)
	item.bgOverlay = bgOverlay
	
	item.height = bg:height()
	item.width = bg:width()
	
	local font = "zombie_font_description"
	textGfx = obj:addTextRaster(font, name, 0, -13*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Right, 220*menuScale)
	textGfx:SetLayerByName(layer)
	--textGfx:center()
	textGfx:SetPriority(priority-4)
	item.titleText = textGfx
	
	local prefix = ""
	if (data.power_ ~= 0) then
		hasBonus = true
		if (data.power_ > 0) then
			prefix = "+"
		else
			prefix = ""
		end
		bonusString = bonusString .. prefix .. data.power_ .. " " .. game.getLocalizedText("POWER")
	end
	if (data.contact_ ~= 0 and bonusString ~= "") then
		bonusString = bonusString .. "\n"
	end
	
	if (data.contact_ ~= 0) then
		hasBonus = true
		if (data.contact_ > 0) then
			prefix = "+"
		else
			prefix = ""
		end
		bonusString = bonusString .. prefix .. data.contact_ .. " " .. game.getLocalizedText("CONTACT")
	end
	if (data.vision_ ~= 0 and bonusString ~= "") then
		bonusString = bonusString .. "\n"
	end
	
	if (data.vision_ ~= 0) then
		hasBonus = true
		if (data.vision_ > 0) then
			prefix = "+"
		else
			prefix = ""
		end
		bonusString = bonusString .. prefix .. data.vision_ .. " " .. game.getLocalizedText("VISION")
	end
	
	item.hasBonus = hasBonus
	if (not hasBonus) then
		locked = false
	end
	
	if (category == ItemCategory["POWERUP"]) then
		local infoButton = Button.new("xml_resources/sprite_menu.xml", "btn_green", "HUD", priority-2, obj, 162*menuScale, 55*menuScale, menuScale, menuScale)
		infoButton.gameobject:setTag("infoButton")
		infoButton:setText(game.getLocalizedText("MORE_INFO"))
		infoButton.onTouchUp = function()
			--game.showEquipmentInfo(data.name_, data.description_)
			game.showPowerUpInfo(data)
		end
		infoButton:setSpamDelay(75)
		item.infoButton = infoButton
	elseif (isIAP) then
	
		if (group == "convert") then
			textGfx = obj:addTextRaster(font, "+"..data.stack_, 145*menuScale, 33*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Left, 100*menuScale)
			textGfx:SetLayerByName(layer)
			textGfx:SetPriority(priority-2)
			
			local goldIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_gold", 127*menuScale, 47*menuScale, menuScale, menuScale)
			goldIcon:SetLayerByName("HUD")
			goldIcon:SetPriority(priority-4)
			goldIcon:center()
			
			local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_platinum", 120*menuScale, 92*menuScale, menuScale, menuScale)
			moneyIcon:SetLayerByName("HUD")
			moneyIcon:SetPriority(priority-4)
			moneyIcon:center()
			item.moneyIcon = moneyIcon
		else
			if( data.stack_ > 0 ) then
				textGfx = obj:addTextRaster(font, "+"..data.stack_, 145*menuScale, 33*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Left, 100)
			else
				textGfx = obj:addTextRaster(font, game.getLocalizedText("FREE"), 145*menuScale, 33*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Left, 100)
			end
			textGfx:SetLayerByName(layer)
			textGfx:SetPriority(priority-2)
			
			local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_platinum", 127*menuScale, 47*menuScale)
			moneyIcon:SetLayerByName("HUD")
			moneyIcon:SetPriority(priority-4)
			moneyIcon:center()
			item.moneyIcon = moneyIcon
		end
		
	else
		if (hasBonus) then
			--textGfx = obj:addTextRaster(font, bonusString, 87, 28, 0.5, 0.5, game.GfxText_Format_Center, 150)
			textGfx = obj:addTextRaster(font, bonusString, 115*menuScale, 37*menuScale, 0.5*menuScale, 0.5*menuScale, game.GfxText_Format_Left, 180)
			textGfx:SetLayerByName(layer)
			textGfx:SetPriority(priority-2)
		end
	end

	item.name = name
	
	local ypos = 56
	if (item.category == ItemCategory["HAT"]) then --Hats have a lot of whitespace below them
		ypos = 67
	end
	local itemImage = obj:addSpriteSheet(sheet, image, 52*menuScale, ypos*menuScale, menuScale, menuScale)
	itemImage:SetLayerByName("HUD")
	itemImage:SetPriority(priority-1)
	itemImage:center()
	
	item.layer = layer or "HUD"
	item.priority = priority or 50
	
	if parent then
		obj:setParent(parent)
	end
	
	local x = xPos or 0
	local y = yPos or 0
	obj:setPos(x*menuScale, y*menuScale)
	
	function item:setBought(bought)
		if (bought) then
			--game.GetGameWorld():destroyGameObject(item.purchaseButton.gameobject)
			item.purchaseButton:setText(game.getLocalizedText("EQUIP"))
			item.moneyIcon:SetPriority(100)
			item.bought = true
			item.bgSprite:setSpriteName("item_card_purchased")
		else
			item.bought = false
		end
	end
	
	function item:setEquipped(equipped)
		if (equipped) then
			--game.GetGameWorld():destroyGameObject(item.purchaseButton.gameobject)
			item.purchaseButton:setText(game.getLocalizedText("EQUIPPED"))
			--item.bought = true
			item.bgSprite:setSpriteName("item_card_equipped")
		else
			if (item.bought) then
				item.purchaseButton:setText(game.getLocalizedText("EQUIP"))
				item.bgSprite:setSpriteName("item_card_purchased")
			else
				item.bgSprite:setSpriteName("item_card")
			end
		end
	end
	
	function item:setLocked(locked, animate)
		item.locked = locked
		if (locked) then
			--item.purchaseButton:setSpriteName("btn_red")
			--item.moneyIcon:setSpriteName("btn_close")
			item.titleText:changeText("")
			item.bgOverlay:SetAlpha(255)
		else
			item.titleText:changeText(name)
			if (animate) then
				local action = lockObj:moveAlpha( -1.0, 1, lua_sys.Quadratic_EASEOUT )
				action:start()
				--ActionHelper.waitForAction(action)
			else
				item.bgOverlay:SetVisible(false)
			end
		end
	end
	
	item.bought = false
	--button to send a gift to this friend
	local btnImg = "btn_green"
	local purchaseButton = Button.new("xml_resources/sprite_menu.xml", btnImg, "HUD", priority-2, obj, 162*menuScale, 93*menuScale, true, menuScale)
	purchaseButton.gameobject:setTag("purchaseButton")
	purchaseButton:setSpamDelay(50)
	
	if (isIAP) then
		if (group == "convert") then
			purchaseButton:setText("" .. data.platinumValue_)
		else
			if( isIAP and data.stack_ == 0 ) then
				purchaseButton:setText(game.getLocalizedText("FREE"))
			else
				purchaseButton:setText("$" .. (price/100))
			end
		end
	else
		purchaseButton:setText("" .. price)
	end
	
	purchaseButton.onTouchUp = function()
		print("purchase on touch up")
		if (item.locked) then
			print("item locked")
			return
		end
		if (item.bought) then
			print("item bought")
			game.equipItem(item.category, item.id)
			item:setEquipped(true)
			return
		else
			if (group == "convert") then
				local convertplatinumpopup = ConvertPlatinumPopup.new(item, data, obj)
			else
				if( isIAP and data.stack_ == 0 ) then
					game.showTapjoyOffers()
				else
					local obj = game.GetGameWorld():getObjectByTag("StorePurchasePopup")
					if(obj==nil) then
						print("no StorePurchasePopup")
						if(game.hasAmazonStore()==1 and isIAP) then
							game.buyRealItem(data.itemGroupName_, item.id) 
						else
							local storepurchasepopup = StorePurchasePopup.new(price, obj, item, limit, isIAP, name, premium, data)
						end
						purchaseButton:setSpamDelay(50)
					end
				end
			end
		end
		
	end
	item.purchaseButton = purchaseButton
	
	local icon = "coin_gold"
	if (premium) then
		icon = "coin_platinum"
	end
	
	if (not isIAP) then
		local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", icon, 120*menuScale, 92*menuScale, menuScale, menuScale)
		moneyIcon:SetLayerByName("HUD")
		moneyIcon:SetPriority(priority-3)
		moneyIcon:center()
		item.moneyIcon = moneyIcon
	end
	
	if (game.getPlayerItemIsOwned(item.category, item.id)) or (data.isOwned_) then
		if (limit > 0) then
			item:setBought(true)
		end
	end
	
	if(game.getPlayerItemIsEquipped(item.category, item.id)) or (data.activated_) then
		if (limit > 0) then
			item:setEquipped(true)
		end
	end
	
	item:setLocked(locked)
	
	--layer, priority, parent, xPos, yPos, w, h
	--[[local zone = Button.zone("HUD", priority-2, obj, item.width*0.5, item.height*0.5, item.width, item.height)
	zone.onTouchUp = function()
		print("Yolo")
	end
	item.zone = zone--]]
	StoreItem.item = item
	return item
end

StoreItem.showConfirm = function()

end

StoreItem.hideConfirm = function()

end

return StoreItem


