local ActionHelper = include("ActionHelper")
local Button = include("Button")
local StoreItem = include("StoreItem")
local StoreList = include("StoreList")
local StatBar = include("StatBar")
local PopupCurrencyInfo = include("PopupCurrencyInfo")

local StoreMenu = {}

local storeList
local staticObjLayer

local currentCategory
local transitioning = false
local lastButton = nil

local platinumText, goldText, statText
local obj, playerCardObj, menuTabObj, playerAnimObj
local playerSprite

local bar1, bar2, bar3

local listXPos = 0
local listYPos = 0

local basePriority = 50

local menuScale = game.menuScale()

StoreMenu.updateCurrency = function()
	local goldAmount = game.getGoldCoins()
	local platinumAmount = game.getPlatinumCoins()
	goldText:changeText(""..goldAmount)
	platinumText:changeText(""..platinumAmount)
end

StoreMenu.updateStats = function()
	--[[local contact = game.playerTotalContact()
	local vision = game.playerTotalVision()
	local power = game.playerTotalPower()
	local statString = "Contact: " .. contact .. "\nVision: " .. vision .. "\nPower: " .. power
	statText:changeText(statString)--]]
	if (bar1 ~= nil) then
		game.GetGameWorld():destroyGameObject(bar1.gameobject)
		game.GetGameWorld():destroyGameObject(bar2.gameobject)
		game.GetGameWorld():destroyGameObject(bar3.gameobject)
	end
	
	local xpos = 187*menuScale
	local ypos = -90*menuScale
	local spacing = 25*menuScale
	bar1 = StatBar.new(game.getContactStatInfo(), false, "HUD", basePriority-6, playerCardObj, xpos, ypos+spacing*1)
	bar2 = StatBar.new(game.getVisionStatInfo(), false, "HUD", basePriority-6, playerCardObj, xpos, ypos+spacing*2)
	bar3 = StatBar.new(game.getPowerStatInfo(), false, "HUD", basePriority-6, playerCardObj, xpos, ypos+spacing*3)
end

--[[local function waitForPlayerUpdate()
	coroutine.yield({
		game.gameReceiver(), 
		game.M_MsgPlayerChangeEquipment_GetMsgTypeId(),
		function(msg)
			game.remapPlayerAnim(playerSprite)
		end
	})
end--]]

local function waitForMessage()
	-- pull this out so it doesn't get rebuilt every time this is called
	coroutine.yield({
		game.gameReceiver(), 
		game.M_MsgUpdateStoreCurrency_GetMsgTypeId(),
		function(msg)
			StoreMenu.updateCurrency()

		end,
		
		game.gameReceiver(), 
		game.M_MsgPlayerChangeEquipment_GetMsgTypeId(),
		function(msg)
			StoreMenu.updateStats()
			--game.remapPlayerAnim(playerSprite, msg.category)
			playerAnimObj:remapPlayerAnim(msg.category)
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillStoreRoutine_GetMsgTypeId(),
		function(msg)
			print "KILL YOURSELF MENU! DIEEEEEE"
			return true
		end,
		
		game.gameReceiver(), 
		game.M_MsgPlayerPurchaseItem_GetMsgTypeId(),
		function(msg)
			print("Refreshing StoreList!")
			storeList.unlockItem((msg.itemId))
			--We could refresh, but then the user has to find the item again... so lets not.
			--storeList.hide()
			--StoreList.show(StoreMenu.currentCategory, StoreMenu.listXPos, StoreMenu.listYPos, StoreMenu.cardScale)
		end,
		
		game.gameReceiver(), 
		game.M_MsgPlayerEquipItem_GetMsgTypeId(),
		function(msg)
			storeList.unselectAll()
		end,
		
		game.engineReceiver(), 
		game.M_MsgBoughtCurrency_GetMsgTypeId(),
		function(msg)
			print("You Bought: " .. msg.name_ .. " valued: " .. msg.amount_)
			game.addPlatinumCoins(msg.amount_)
			game.purchasedCoins()
		end
	})
end

StoreMenu.show = function()
	obj = game.GetGameWorld():createGameObject("GameObject")
	obj:setTag("StoreMenu")
	--obj:RunCoroutine(waitForMessage)
	
	playerCardObj = game.GetGameWorld():createGameObject("GameObject")
	playerCardObj:setPos( 0, lua_sys.screenHeight() )
	
	playerAnimObj = game.GetGameWorld():createGameObject("PlayerAnimObject")
	
	menuTabObj = game.GetGameWorld():createGameObject("GameObject")
	menuTabObj:setPos(0, 0)
	
	staticObjLayer = game.GetGameWorld():createGameObject("GameObject")
	staticObjLayer:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	
	local animGfxRef = obj:addSpriteSheet("xml_resources/sprite_guy.xml", "", 0, 0)
	animGfxRef:SetScale(0,0,0)
	animGfxRef:SetAlpha(0)
	
	--staticObjLayer:setTag("StaticObjLayer")
	local tabBar = menuTabObj:addSpriteSheet("xml_resources/sprite_store.xml", "tab_bar", 0, -9*menuScale, menuScale, menuScale)
	tabBar:SetLayerByName("HUD")
	tabBar:SetPriority(basePriority-7)
	tabBar:setVAnchor(game.Gfx_VA_ALIGN_TOP)
	tabBar:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	local card_scale = (lua_sys.screenHeight() - tabBar:height()-10) / (lua_sys.screenHeight())
	card_scale = card_scale
	playerCardObj:setScale(card_scale, card_scale)
	
	--Create tabs...
	local categoryData = game.Categories()
	game.read(categoryData)
	local numTabs = categoryData.category:size()
	for i=0,categoryData.category:size()-1 do
		local spacing = (lua_sys.screenWidth()-45*menuScale) / numTabs
		local xpos = 45*menuScale + (spacing * (i)) --lua_sys.screenWidth()
		local ypos = 17*menuScale
		
		local tabButton = Button.new("xml_resources/sprite_store.xml", categoryData.category[i].iconSprite, "HUD", basePriority-10, menuTabObj, xpos, ypos, false, menuScale)
		xpos = xpos + tabButton.upSprite:width() * 0.5
		tabButton.gameobject:setPos(xpos, ypos)
		tabButton.isActive = false
		tabButton.onTouchUp = function() 
			if (transitioning or tabButton.isActive) then return end
			
			if (lastButton ~= nil) then
				lastButton.resetPosition()
			end
			lastButton = tabButton
			tabButton.gameobject:setPos(xpos, ypos + 10*menuScale)
			tabButton.isActive = true
			
			transitioning = true
			currentCategory = categoryData.category[i].id
			if( storeList ~= nil ) then
				print ("hiding store list")
				storeList.hide()
			end
			storeList = StoreList.show(currentCategory, listXPos, listYPos, card_scale)
			
			StoreMenu.currentCategory = currentCategory
			StoreMenu.listXPos = listXPos
			StoreMenu.listYPos = listYPos
			StoreMenu.cardScale = card_scale
			
			
			transitioning = false
		end
		
		tabButton.resetPosition = function()
			tabButton.gameobject:setPos(xpos, ypos)
			tabButton.isActive = false
		end
		
		if (i == 0) then
			lastButton = tabButton
		end
	end

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_home_small", "HUD", basePriority-10, staticObjLayer, -lua_sys.screenWidth()*0.5 + 23*menuScale, -lua_sys.screenHeight()*0.5+23*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		StoreMenu.hide()
	end
	
	local ypos = -290
	local xpos = 195
	local btn_boy = Button.new("xml_resources/sprite_store.xml", "btn_gender_male", "HUD", basePriority-10, playerCardObj, xpos*menuScale, ypos*menuScale, true, menuScale)
	btn_boy.onTouchUp = function() 
		if (game.getSelectedCharacter() ~= 0) then
			game.setSelectedCharacter(0)

			playerAnimObj:setGender(true)
			playerAnimObj:getAnim():SetLayerByName("HUD")
			playerAnimObj:getAnim():SetPriority(basePriority-6)
		end
	end
	
	local btn_girl = Button.new("xml_resources/sprite_store.xml", "btn_gender_female", "HUD", basePriority-10, playerCardObj, (xpos+40)*menuScale, ypos*menuScale, true, menuScale)
	btn_girl.onTouchUp = function() 
		if (game.getSelectedCharacter() ~= 1) then
			game.setSelectedCharacter(1)
			playerAnimObj:setGender(false)
			playerAnimObj:getAnim():SetLayerByName("HUD")
			playerAnimObj:getAnim():SetPriority(basePriority-6)
		end
	end

	listXPos = (lua_sys.screenWidth() * 0.5 - 238*menuScale)
	listYPos = (-lua_sys.screenHeight() * 0.5) + (tabBar:height()+10)*menuScale
	
	local playerCard = playerCardObj:addSpriteSheet("xml_resources/sprite_store.xml", "player_card", 0, 0, menuScale, menuScale)
	playerCard:SetLayerByName("HUD")
	playerCard:SetPriority(basePriority-5)
	playerCard:setVAnchor(game.Gfx_VA_ALIGN_BOTTOM)
	playerCard:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	local coin = playerCardObj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_platinum", 5*menuScale, -5*menuScale, menuScale, menuScale)
	coin:SetLayerByName("HUD")
	coin:SetPriority(basePriority-6)
	coin:setVAnchor(game.Gfx_VA_ALIGN_BOTTOM)
	coin:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	local coin = playerCardObj:addSpriteSheet("xml_resources/sprite_menu.xml", "coin_gold", 5*menuScale, -45*menuScale, menuScale, menuScale)
	coin:SetLayerByName("HUD")
	coin:SetPriority(basePriority-6)
	coin:setVAnchor(game.Gfx_VA_ALIGN_BOTTOM)
	coin:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	playerAnimObj = game.CastToPlayerAnim(playerAnimObj)
	playerAnimObj:setScale(0.85 * card_scale * menuScale, 0.85 * card_scale * menuScale)
	playerAnimObj:setPos(130 * menuScale * card_scale, lua_sys.screenHeight() - 210 * menuScale * card_scale)
	playerAnimObj:getAnim():SetLayerByName("HUD")
	playerAnimObj:getAnim():SetPriority(basePriority-6)
	
	goldText = playerCardObj:addTextRaster("zombie_font_description", "", 40*menuScale, -47*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Left, 150* menuScale)
	goldText:SetLayerByName("HUD")
	goldText:SetPriority(basePriority-6)
	goldText:setVAnchor(game.Gfx_VA_ALIGN_BOTTOM)
	goldText:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	platinumText = playerCardObj:addTextRaster("zombie_font_description", "", 40*menuScale, -7*menuScale, 0.7*menuScale, 0.7*menuScale, game.GfxText_Format_Left, 150* menuScale)
	platinumText:SetLayerByName("HUD")
	platinumText:SetPriority(basePriority-6)
	platinumText:setVAnchor(game.Gfx_VA_ALIGN_BOTTOM)
	platinumText:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	
	--[[statText = playerCardObj:addTextRaster("zombie_font_description", "", 142, -75, 0.5, 0.5, game.GfxText_Format_Left, 115)
	statText:SetLayerByName("HUD")
	statText:SetPriority(basePriority-6)
	statText:setVAnchor(game.Gfx_VA_ALIGN_TOP)
	statText:setHAnchor(game.Gfx_HA_ALIGN_LEFT)
	statText:setLineSpacing(1.75)--]]

	StoreMenu.updateCurrency()
	StoreMenu.updateStats()
	
	lastButton.onTouchUp()
	
	if( game.showStoreTutorial() ) then
		PopupCurrencyInfo.show()
		game.disableStoreTutorial()
	end
end

StoreMenu.hide = function()
	--storeList.hide()
	StoreList.hide()
	
	local obj = game.GetGameWorld():getObjectByTag("StoreMenu")
	--local staticObjLayer = game.GetGameWorld():getObjectByTag("StaticObjLayer")
	
	if obj then
		local action = obj:movePosition( lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
		action:start()
		--local action2 = staticObjLayer:movePosition( -lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
		--action2:start()
		ActionHelper.waitForAction(action)
		game.GetGameWorld():destroyGameObject(obj)
		
		if staticObjLayer  then
			game.GetGameWorld():destroyGameObject(staticObjLayer)
		end
		
		if playerCardObj then
			game.GetGameWorld():destroyGameObject(playerCardObj)
		end
		
		if playerAnimObj then
			game.GetGameWorld():destroyGameObject(playerAnimObj)
		end
		
		if menuTabObj then
			game.GetGameWorld():destroyGameObject(menuTabObj)
		end
		
	else
		print("Where'd options go?")
	end
	
	game.killStoreRoutine()
	
	game.loadMenu("main_menu")
end

StoreMenu.show()
waitForMessage()
--RunCoroutine(waitForMessage)
--return StoreMenu