local ActionHelper = include("ActionHelper")

SwipeComponent = {}

local function waitForInput( swipecomponent )

	local x = 0
	local y = 0
	local touchDownX = 0
	local touchDownY = 0
	local dt = 0
	
	local curY = 0
	local lastY = 0
	local dragging = false
	local difY = 0
	local vel = 0
	local friction = 0.96
	local lastVel = 0
	local ticksToReset = 0
	local swipeScrollSensitivity = 6

	while true do
			
			local event = nil
			local tickEvent = false
			
			coroutine.yield({
				swipecomponent.obj, 
				game.M_MsgGameObjectTouchEvent_GetMsgTypeId(),
				function(msg) 
					event = msg.event -- need to capture the event because we can't yield from here
					x = msg.x
					y = msg.y
					return true 
				end,
				
				swipecomponent.obj, 
				game.M_MsgUpdate_GetMsgTypeId(),
				function(msg) 
					tickEvent = true
					dt = msg.time
					return true
				end
			})
			
			if event == game.TouchEvent_Down then
				dragging = true
				--print ("Friends touch down")
				touchDownX = x
				touchDownY = y
				
				lastY = y
				vel = 0
				difY = 0
			elseif event == game.TouchEvent_Cancel then
				--print("CANCEL")
				dragging = false
				--print ("Friends touch cancel y:"..swipecomponent.obj:y())
				if (swipecomponent.obj:y() < swipecomponent.upperLimit ) then
					--print ("Friends touch cancel upperLimit"..swipecomponent.upperLimit)
					local action = swipecomponent.gameobjects:movePosition( 0, swipecomponent.upperLimit - swipecomponent.obj:y(), 0.5, lua_sys.Back_EASEOUT )
					action:start()
					ActionHelper.waitForAction(action)
					
					swipecomponent.obj:setPos( 0, swipecomponent.upperLimit )
				elseif (swipecomponent.obj:y() > swipecomponent.lowerLimit ) then 
					--print ("Friends touch cancel lowerLimit"..swipecomponent.lowerLimit)
					
					local action = swipecomponent.gameobjects:movePosition( 0, swipecomponent.lowerLimit - swipecomponent.obj:y(), 0.5, lua_sys.Back_EASEOUT )
					action:start()
					ActionHelper.waitForAction(action)
					
					swipecomponent.obj:setPos( 0, swipecomponent.lowerLimit )
				end
				 
			elseif event == game.TouchEvent_Up then
				--print("UP")
				dragging = false
				tickEvent = false
				--print ("Friends touch up y:"..swipecomponent.obj:y())
				
				if( swipecomponent.obj:y() < swipecomponent.upperLimit ) then
					vel = 0
					local action = swipecomponent.gameobjects:movePosition( 0, swipecomponent.upperLimit - swipecomponent.gameobjects:y(), 0.5, lua_sys.Back_EASEOUT )
					action:start()
					ActionHelper.waitForAction(action)
					
					swipecomponent.obj:setPos( 0, swipecomponent.upperLimit )
				elseif (swipecomponent.obj:y() > swipecomponent.lowerLimit ) then 
					vel = 0
					--swipecomponent.gameobjects:setPos( 0, swipecomponent.obj:y())
					local action = swipecomponent.gameobjects:movePosition( 0, swipecomponent.lowerLimit - swipecomponent.gameobjects:y(), 0.5, lua_sys.Back_EASEOUT )
					action:start()
					ActionHelper.waitForAction(action)
					
					swipecomponent.obj:setPos( 0, swipecomponent.lowerLimit )
				else
					vel = difY
				end
			elseif event == game.TouchEvent_Drag then
				local offsetX = 0
				local offsetY = 0
				offsetY = touchDownY - y
				touchDownY = y
				
				lastY = swipecomponent.obj:y()
				swipecomponent.obj:setPos( swipecomponent.obj:x(), swipecomponent.obj:y()-offsetY )
				swipecomponent.gameobjects:setPos( swipecomponent.gameobjects:x(), swipecomponent.obj:y()-offsetY )
				curY = swipecomponent.obj:y()
				
				difY = lastY - curY
				ticksToReset = 0
			end
			
			if tickEvent then
			
				if (not dragging) then
					lastVel = vel
					vel = vel * friction
					if (vel > 0.08 or vel < -0.08) then
						if( swipecomponent.obj:y() < swipecomponent.upperLimit ) then
							vel = 0
							swipecomponent.obj:setPos( 0, swipecomponent.upperLimit )
							--print("< UPPER")
						elseif (swipecomponent.obj:y() > swipecomponent.lowerLimit ) then 
							vel = 0
							swipecomponent.obj:setPos( 0, swipecomponent.lowerLimit )
							--print("> LOWER")
						else
							swipecomponent.obj:setPos( swipecomponent.obj:x(), swipecomponent.obj:y()-vel )
						end
					else
						vel = 0
					end
					if (lastVel ~= vel) then
						--print ("Vel: " .. vel)
					end
				else
					--print ("curY: " .. curY)
					--print ("Dif: " .. difY)
					ticksToReset = ticksToReset + 1
					if (ticksToReset > swipeScrollSensitivity) then
						vel = 0
						difY = 0
						--print("Reset tick!")
					end
				end
				
				swipecomponent.gameobjects:setPos( swipecomponent.gameobjects:x(), swipecomponent.obj:y() )
				
				if (swipecomponent) then
					swipecomponent:tick()
				end
			end
			
			event = nil
		end

end



SwipeComponent.destroy = function()
	local obj = game.GetGameWorld():getObjectByTag("SwipeComponent")
	game.GetGameWorld():destroyGameObject(obj)
end

SwipeComponent.new = function(width, height, layer, priority, objects, xPos, yPos)

	local swipecomponent = {}
	
	function swipecomponent:setUpperLimit(limit)
		self.upperLimit = limit;
	end

	function swipecomponent:setLowerLimit(limit)
		self.lowerLimit = limit;
	end
	
	function swipecomponent:tick() 
		--print "tick..."
	end
	
	swipecomponent.layer = layer or "HUD"
	swipecomponent.priority = priority or 50
	swipecomponent.upperLimit = lua_sys.screenHeight() * 0.5
	swipecomponent.lowerLimit = lua_sys.screenHeight() * 0.5
		
	swipecomponent.obj = game.GetGameWorld():createGameObject("GameObject");
	swipecomponent.obj:setTag("SwipeComponent")

	swipecomponent.gameobjects = objects
	
	local x = xPos or 0
	local y = yPos or lua_sys.screenHeight() * 0.5
	swipecomponent.obj:setPos(x, y)
	
	local touch = swipecomponent.obj:addTouch( width, height, priority )
	touch:setAnchor( 0, lua_sys.screenHeight() * 0.5 )
	
	--would be nice if we could run the coroutine (lua function) on a gameobject
	--from inside lua so that when the object dies, it cleans up the coroutine
	RunIndyCoroutine( waitForInput, swipecomponent )
	
	return swipecomponent

end

return SwipeComponent


