local ActionHelper = include("ActionHelper")
local Button = include("Button")
local HelpScreen = include("HelpScreen")

local TutorialSelect = {}

local menuScale = game.menuScale()

TutorialSelect.show = function()
	--All the generic stuff
	local basePriority = 30

	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("TutorialSelect")
	
	local textObj = game.GetGameWorld():createGameObject("GameObject");
	textObj:setTag("TutorialSelectText")
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG2")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("POPUP")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), basePriority )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)

	local titleText = game.getLocalizedText("HELP_TUTORIALS")
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_large", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)
	
	local title = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(titleText), 0, -bg:height()/2, 0.8*menuScale, 0.8*menuScale, game.GfxText_Format_Center, 355, true )
	title:SetLayerByName("POPUP")
	title:center()
	title:SetPriority(basePriority-2)

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, (-bg:height() * 0.5 + 3)*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		TutorialSelect.hide()
	end

	
	local items = game.getTutorials()
	
	local i_posY = -bg:height() * 0.2 * menuScale
	local i_posX = -bg:width() * 0.3 * menuScale
	local posY = i_posY
	local posX = i_posX
	local spacingY = 55 * menuScale
	local spacingX = 110 * menuScale
	local pos = 0

	for i = 0, items:size()-1, 1 do
		local name = items[i].name_
		local tutorialId = items[i].spriteId_
		pos = pos + 1
		local tutorialBtn = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, posX, posY, true, menuScale)
		tutorialBtn:setText(game.getLocalizedText(name))
		tutorialBtn.onTouchUp = function() 
			HelpScreen.show(tutorialId, true)
		end
		
		posX = posX + spacingX
		
		if ((pos) % 3 == 0) and (pos > 0) then
			posY = posY + spacingY
			posX = i_posX
		end
	end
	
	--Animate in
	textObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	textObj:setAlpha(0.0)
	
	obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	obj:setScale(0.0, 1.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)

	action = textObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
end

TutorialSelect.hide = function()

	local obj = game.GetGameWorld():getObjectByTag("TutorialSelect")
	local textObj = game.GetGameWorld():getObjectByTag("TutorialSelectText")
	local fadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG2")
	if obj then
		local action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		if fadedBGObj then
			game.GetGameWorld():destroyGameObject(fadedBGObj)
		end
	
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)
		
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(obj)
	end

	game.killCoroutine("TutorialSelect")
end

TutorialSelect.show()
--return TutorialSelect