local venueId = ...

local ActionHelper = include("ActionHelper")
local Button = include("Button")

local VenuePopup = {}

local totalCoinObj
local totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
local totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()

local menuScale = game.menuScale()

local function waitForMessage()
	coroutine.yield({
		game.gameReceiver(), 
		game.M_MsgUpdateStoreCurrency_GetMsgTypeId(),
		function(msg)
			print("updating currency")
			totalNumOfCoins = game.getGoldCoins() - game.getGoldRewardCoinsEarned()
			totalNumofPlatinum = game.getPlatinumCoins() - game.getPlatinumRewardCoinsEarned()
			VenuePopup.totalCoinGfx:changeText(""..totalNumOfCoins)
			VenuePopup.totalPlatinumGfx:changeText(""..totalNumofPlatinum)
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillCoroutine_GetMsgTypeId(),
		function(msg)
			local ROUTINE = "VenuePopup"
			if (msg.menu == ROUTINE) then
				print("Killing "..ROUTINE.." Routine...")
				return true
			end
		end
	})
end

VenuePopup.show = function()
	--All the generic stuff
	local basePriority = 40

	local obj = game.GetGameWorld():createGameObject("GameObject");
	obj:setTag("VenuePopup")
	
	local textObj = game.GetGameWorld():createGameObject("GameObject");
	textObj:setTag("VenuePopupText")
	
	local fadedBGObj = game.GetGameWorld():createGameObject("GameObject");
	fadedBGObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	fadedBGObj:setTag("FadedBG")
	
	local fadedBG = fadedBGObj:addSprite("gfx/menu/bg/background")
	fadedBGObj:setScale( lua_sys.screenWidth()/fadedBG:width(), lua_sys.screenHeight()/fadedBG:width() )
	fadedBG:SetLayerByName("HUD")
	fadedBG:center()
	fadedBG:SetPriority(basePriority)
	fadedBG:SetAlpha(200)
	
	local touch = obj:addTouch( lua_sys.screenWidth(), lua_sys.screenHeight(), 40 )
	touch:setAnchor( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	touch:setEnabled(1)
	
	local mainButton = Button.zone("POPUP", basePriority-1, obj, 0, 0, lua_sys.screenWidth(), lua_sys.screenHeight())
	mainButton.onTouchUp = function() 
		VenuePopup.hide()
	end

	--Customized stuff for different popups
	local venueData = game.getVenueInfo(venueId)
	
	local titleText = venueData.name_
	local infoText = venueData.description_
	
	local bg = obj:addSpriteSheet("xml_resources/sprite_menu.xml", "box_large", 0, 0, menuScale, menuScale)
	bg:SetLayerByName("POPUP")
	bg:center()
	bg:SetPriority(basePriority-1)
	
	local premium = false
	local price = venueData.goldValue_
	if (venueData.platinumValue_ > 0) then
		premium = true
		price = venueData.platinumValue_
	end
	
	if (price > 0 and not venueData.purchased_) then --NEEDS TO BE BOUGHT
		local icon = "coin_gold"
		if (premium) then
			icon = "coin_platinum"
		end
		
		local moneyIcon = obj:addSpriteSheet("xml_resources/sprite_menu.xml", icon, 45*menuScale, 55*menuScale, menuScale, menuScale)
		moneyIcon:SetLayerByName("POPUP")
		moneyIcon:SetPriority(basePriority-4)
		moneyIcon:center()
		
		local buttonPurchase = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-2, obj, 90*menuScale, 55*menuScale, true, menuScale)
		buttonPurchase.gameobject:setTag("buttonPurchase")
		buttonPurchase:setText( game.getLocalizedText(""..price) )
		buttonPurchase.onTouchUp = function()
			if ( game.purchaseVenue(venueData.id_) ) then
				game.playSfx("audio/sfx/cash_register.wav")
				VenuePopup.hide()
				game.setCurrentVenue(venueData.id_)
				game.showObjectiveSummary()
			else
				print("Not enough currency to buy!")
				game.showNoMoneyPrompt()
			end
		end
		
		totalCoinObj = game.GetGameWorld():createGameObject("GameObject")
		totalCoinObj:setTag("totalCoinObj")
		totalCoinObj:setParent(obj)
		
		-- total coin obj
		local totalCoinGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "basic_currency_gold_coin_b", 0, 0, 0.7*menuScale, 0.7*menuScale)
		totalCoinGfx_icon:SetLayerByName("POPUP")
		totalCoinGfx_icon:SetPriority(basePriority-2)
		totalCoinGfx_icon:center()

		-- current total coins
		text = totalNumOfCoins
		totalCoinGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 25, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalCoinGfx:SetLayerByName("POPUP")
		totalCoinGfx:SetPriority(basePriority-2)
		totalCoinGfx:left_center()
		VenuePopup.totalCoinGfx = totalCoinGfx
		
		-- platinum gfx
		local totalPlatinumGfx_icon = totalCoinObj:addSpriteSheet( "xml_resources/bb_icons.xml", "premium_currency_platinum_coin", 150, 0, 0.7*menuScale, 0.7*menuScale )
		totalPlatinumGfx_icon:SetLayerByName("POPUP")
		totalPlatinumGfx_icon:SetPriority(basePriority-2)
		totalPlatinumGfx_icon:center()
		
		-- current platinum coins
		text = totalNumofPlatinum
		totalPlatinumGfx = totalCoinObj:addTextRaster( game.getDescriptionFont(), text, 175, 0, 1*menuScale, 1*menuScale, game.GfxText_Format_Left )
		totalPlatinumGfx:SetLayerByName("POPUP")
		totalPlatinumGfx:SetPriority(basePriority-2)
		totalPlatinumGfx:left_center()
		VenuePopup.totalPlatinumGfx = totalPlatinumGfx
		
		totalCoinObj:setPos( -game.windowSizeX()*0.5 + 30*menuScale, game.windowSizeY()*0.5 - 30*menuScale)
	else --ALREADY BOUGHT
	
		if (venueData.challengeUnlocked_) then
			local buttonPlay = Button.new("xml_resources/sprite_menu.xml", "btn_yellow", "POPUP", basePriority-2, obj, 95*menuScale, 20*menuScale, true, menuScale)
			buttonPlay.gameobject:setTag("buttonPlay")
			buttonPlay:setText( game.getLocalizedText("CHALLENGE") )
			buttonPlay.onTouchUp = function()
				VenuePopup.hide()
				game.setCurrentVenue(venueData.id_)
				game.showChallengerPopup()
			end
		end
		
		local buttonPlay = Button.new("xml_resources/sprite_menu.xml", "btn_green", "POPUP", basePriority-3, obj, 95*menuScale, 55*menuScale, true, menuScale)
		buttonPlay.gameobject:setTag("buttonPlay")
		buttonPlay:setText( game.getLocalizedText("PLAY") )
		buttonPlay.onTouchUp = function()
			VenuePopup.hide()
			game.setCurrentVenue(venueData.id_)
			game.showObjectiveSummary()
		end

	end

	local title = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(titleText), 0,  -bg:height() * 0.53 * menuScale, 0.8*menuScale, 0.8*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
	--local title = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(titleText), 0, -bg:height()/2, 0.8*menuScale, 0.8*menuScale, game.GfxText_Format_Center, 355*menuScale, true )
	title:SetLayerByName("POPUP")
	title:center()
	title:SetPriority(basePriority-2)

	local description = textObj:addTextRaster("zombie_font_description", game.getLocalizedText(infoText), 100*menuScale, -55*menuScale, 0.45*menuScale, 0.45*menuScale, game.GfxText_Format_Left, 150*menuScale, true )
	description:SetLayerByName("POPUP")
	description:center()
	description:SetPriority(basePriority-2)

	local icon = obj:addSpriteSheet("xml_resources/sprite_map.xml", venueData.pictureSprite_, (-bg:width()*menuScale/2)+100*menuScale, 5*menuScale, menuScale, menuScale)
	icon:SetLayerByName("POPUP")
	icon:center()
	icon:SetPriority(basePriority-2)
	
	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_close", "POPUP", basePriority-2, obj, -175*menuScale, -bg:height() * 0.5 * menuScale + 3*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		VenuePopup.hide()
	end

	if (totalCoinObj) then
		totalCoinObj:setAlpha(0.0)
	end
	
	--Animate in
	textObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	textObj:setAlpha(0.0)
	
	obj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	obj:setScale(0.0, 1.0)
	
	local action = obj:moveScale( 1.0, 0, 0.45, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	if (totalCoinObj) then
		local action2 = totalCoinObj:moveAlpha( 1.0, 0.45, lua_sys.Back_EASEOUT )
		action2:start()
	end

	action = textObj:moveAlpha( 1.0, 0.15, lua_sys.Quadratic_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	waitForMessage()
end

VenuePopup.hide = function()
	local obj = game.GetGameWorld():getObjectByTag("VenuePopup")
	local textObj = game.GetGameWorld():getObjectByTag("VenuePopupText")
	local fadedBGObj = game.GetGameWorld():getObjectByTag("FadedBG")
	if obj then
		--[[local action = textObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
		action:start()
		if (totalCoinObj) then
			local action2 = totalCoinObj:moveAlpha( -1.0, 0.1, lua_sys.Quadratic_EASEIN )
			action2:start()
		end
		ActionHelper.waitForAction(action)
		
		action = obj:moveScale( -1.0, 0, 0.25, lua_sys.Quadratic_EASEIN )
		action:start()
		ActionHelper.waitForAction(action)]]
		
		if fadedBGObj then
			game.GetGameWorld():destroyGameObject(fadedBGObj)
		end
		game.GetGameWorld():destroyGameObject(textObj)
		game.GetGameWorld():destroyGameObject(obj)
	end
	
	game.killCoroutine("VenuePopup")
end

VenuePopup.show()