local ActionHelper = include("ActionHelper")
local Button = include("Button")
local StatBar = include("StatBar")
local ProgressBar = include("ProgressBar")

local VenueSelect = {}

local staticObjLayer
local mapObj
local obj
local fakeObj

local buttons = {}

local menuScale = game.menuScale()

VenueSelect.updateCurrency = function()
	local goldAmount = game.getGoldCoins()
	local platinumAmount = game.getPlatinumCoins()
	goldText:changeText(""..goldAmount)
	platinumText:changeText(""..platinumAmount)
end

VenueSelect.updateStats = function()
	local contact = game.playerTotalContact()
	local vision = game.playerTotalVision()
	local power = game.playerTotalPower()
	local statString = "Contact: " .. contact .. "\nVision: " .. vision .. "\nPower: " .. power
	statText:changeText(statString)
end

VenueSelect.updateVenue = function( venueId )
	print ("venueID: "..venueId)
	if (buttons[venueId] ~= nil) then
		
		local objB = buttons[venueId].obj
		local arrowX = objB:x()
		local arrowY = objB:y()
		local priority = buttons[venueId].priority
		
		print ("Priority"..priority)
		game.GetGameWorld():destroyGameObject(objB)
		
		local arrowObj = game.GetGameWorld():createGameObject("GameObject")
		arrowObj:setParent(mapObj)
		arrowObj:setPos(arrowX, arrowY)
		local arrowBtn = Button.new("xml_resources/sprite_map.xml", "arrow", "MAP", priority, arrowObj, 0, 0, false, menuScale)
		arrowBtn.onTouchUp = function()
			game.showVenuePopup(venueId)
		end
	end
end

local function waitForMessage()
	-- pull this out so it doesn't get rebuilt every time this is called
	coroutine.yield({
		game.gameReceiver(),
		game.M_MsgPurchasedVenue_GetMsgTypeId(),
		function(msg)
			print "UNLOCKED VENUE"
			VenueSelect.updateVenue(msg.venueId)
		end,
		
		game.gameReceiver(), 
		game.M_MsgKillCoroutine_GetMsgTypeId(),
		function(msg)
			local ROUTINE = "VenueSelect"
			if (msg.menu == ROUTINE) then
				print("Killing "..ROUTINE.." Routine...")
				return true
			end
		end
	})
end

VenueSelect.show = function()
	local basePriority = 50
	
	obj = game.GetGameWorld():createGameObject("GameObject")
	obj:setTag("VenueSelect")

	staticObjLayer = game.GetGameWorld():createGameObject("GameObject")
	staticObjLayer:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	
	mapObj = game.GetGameWorld():createGameObject("GameObject")
	mapObj:setTag("MapObject")
	--mapObj:setPos( lua_sys.screenWidth() * 0.5, lua_sys.screenHeight() * 0.5 )
	
	local mapTitle = staticObjLayer:addSpriteSheet("xml_resources/sprite_map.xml", "map_title", 0, -lua_sys.screenHeight() * 0.5 + 22*menuScale, 0.8*menuScale, 0.8*menuScale)
	mapTitle:SetLayerByName("MAP")
	mapTitle:SetPriority(basePriority-1)
	mapTitle:center()
	
	--Create tabs...
	local venueData = game.getPlayerVenues()
	local numTabs = venueData:size()
	
	for i=0,venueData:size()-1 do
		if (venueData[i].unlocked_) then
		
			local premium = false
			local price = venueData[i].goldValue_
			if (venueData[i].platinumValue_ > 0) then
				premium = true
				price = venueData[i].platinumValue_
			end

			local sprite = "arrow"
			if (price > 0 and not venueData[i].purchased_) then
				sprite = "arrow_lock"
			end
			if (venueData[i].challengeUnlocked_ and not venueData[i].challengeComplete_ ) then
				sprite = "arrow_challenge"
			elseif (venueData[i].challengeUnlocked_ and venueData[i].challengeComplete_ and game.allMissionsCompleted(i) < 15 ) then
				sprite = "arrow_gold"
			elseif (venueData[i].challengeUnlocked_ and venueData[i].challengeComplete_ and game.allMissionsCompleted(i) == 15 ) then
				sprite = "arrow_platinum"
			end
			
			local arrowObj = game.GetGameWorld():createGameObject("GameObject")
			arrowObj:setParent(mapObj)
			arrowObj:setPos(venueData[i].map_x_*menuScale, venueData[i].map_y_*menuScale)
			local arrowBtn = Button.new("xml_resources/sprite_map.xml", sprite, "MAP", basePriority-(i+2), arrowObj, 0, 0, false, menuScale)
			--[[arrowBtn.onTouchUp = function()
				game.showVenuePopup(venueData[i].id_)
			end--]]
			buttons[i] = {}
			buttons[i].obj = arrowObj
			buttons[i].priority = basePriority-(i+2)
			
			local touchSize = 75*menuScale
			local touchObject = Button.zone("MAP", basePriority-(i+3), mapObj, (venueData[i].map_x_+10)*menuScale, (venueData[i].map_y_+5)*menuScale, touchSize, touchSize)
			touchObject.onTouchUp = function()
				print("venueData[i].id_"..venueData[i].id_)
				game.showVenuePopup(venueData[i].id_)
			end
			
			local starObject = game.GetGameWorld():createGameObject("GameObject")
			starObject:setParent(mapObj)
			starObject:setPos(venueData[i].map_x_*menuScale, venueData[i].map_y_*menuScale)
			local starSprite = starObject:addSpriteSheet("xml_resources/sprite_map.xml", "star_gold", 4, 0, menuScale, menuScale)
			starSprite:SetLayerByName("MAP")
			starSprite:SetPriority(basePriority-(i+1))
		end
	end

	local closeButton = Button.new("xml_resources/sprite_menu.xml", "btn_home_small", "MAP", basePriority-1, staticObjLayer, -lua_sys.screenWidth()*0.5 + 20*menuScale, -lua_sys.screenHeight()*0.5+20*menuScale, true, menuScale)
	closeButton.onTouchUp = function() 
		VenueSelect.hide()
	end
	
	local map = mapObj:addSpriteSheet("xml_resources/sprite_map.xml", "map", 0, 0, menuScale, menuScale)
	map:SetLayerByName("MAP")
	map:SetPriority(basePriority)
	--map:setVAnchor(game.Gfx_VA_ALIGN_CENTER)
	--map:setHAnchor(game.Gfx_HA_ALIGN_CENTER)
	
	local scaleY = (lua_sys.screenHeight() / map:height())
	local scaleX = (lua_sys.screenWidth() / map:width())
	local scale = scaleY
	if (scaleY > scaleX) then
		scale = scaleX
	end
	--mapObj:setScale(scale, scale)
	
	mapObj:setPos( (lua_sys.screenWidth() - map:width() * scale)/2, (lua_sys.screenHeight() - map:height() * scale)/2 )
	
	local xpos = -lua_sys.screenWidth() * 0.5 + 75 * menuScale
	local ypos = lua_sys.screenHeight() * 0.5 - 95 * menuScale
	local spacing = 25 * menuScale
	local bar1 = StatBar.new(game.getContactStatInfo(), false, "MAP", basePriority, staticObjLayer, xpos, ypos+spacing*1)
	local bar2 = StatBar.new(game.getVisionStatInfo(), false, "MAP", basePriority, staticObjLayer, xpos, ypos+spacing*2)
	local bar3 = StatBar.new(game.getPowerStatInfo(), false, "MAP", basePriority, staticObjLayer, xpos, ypos+spacing*3)
	
	--[[local fatigueBar = ProgressBar.new("gfx/menu/common/stat_empty", "gfx/menu/common/stat_fatigue", "MAP", basePriority, staticObjLayer, lua_sys.screenWidth() * 0.5-50, lua_sys.screenHeight() * 0.5-50)
	fatigueBar:setPercent(1-game.getPlayerFatigue(), 0)
	fatigueBar:setText("Fatigue: " .. math.floor((1-game.getPlayerFatigue())*100).."%")--]]
	game.sendPlayerFatigue()
	
	--ACTIONS
	fakeObj = game.GetGameWorld():createGameObject("GameObject")
			
	for i=0, table.getn(buttons) do
		if (buttons[i] ~= nil) then
			local objB = buttons[i].obj
			buttons[i].x = objB:x()
			buttons[i].y = objB:y()
			objB:setPos( objB:x()-50*menuScale, -lua_sys.screenHeight() )
		end
	end
	
	local posX = mapObj:x()
	local posY = mapObj:y()
	mapObj:setPos( lua_sys.screenWidth(), posY )
	local action = mapObj:movePosition( posX - mapObj:x(), posY - mapObj:y(), 0.6, lua_sys.Back_EASEOUT )
	action:start()
	ActionHelper.waitForAction(action)
	
	for i=0, table.getn(buttons) do
		if (buttons[i] ~= nil) then
			local objB = buttons[i].obj
			local posX = buttons[i].x
			local posY = buttons[i].y
			objB:setPos( posX-50*menuScale, -lua_sys.screenHeight() )
			local action = objB:movePosition( posX - objB:x(), posY - objB:y(), .5, lua_sys.Quadratic_EASEIN )
			action:start()
			
			local action2 = fakeObj:movePosition( 0, 0, .2, lua_sys.Quadratic_EASEIN )
			action2:start()
			ActionHelper.waitForAction(action2)
		end
	end
end

VenueSelect.hide = function()
	local obj = game.GetGameWorld():getObjectByTag("VenueSelect")
	--local staticObjLayer = game.GetGameWorld():getObjectByTag("StaticObjLayer")
	
	if obj then
		--[[local action = obj:movePosition( lua_sys.screenWidth() - obj:x(), 0, 0.5, lua_sys.Quadratic_EASEIN )
		action:start()
		local action2 = mapObj:movePosition( lua_sys.screenWidth() * 2, 0, 0.5, lua_sys.Back_EASEIN )
		action2:start()
		ActionHelper.waitForAction(action)--]]
		game.GetGameWorld():destroyGameObject(obj)
		
		if staticObjLayer  then
			game.GetGameWorld():destroyGameObject(staticObjLayer)
		end
		
		if mapObj  then
			game.GetGameWorld():destroyGameObject(mapObj)
		end
		
		if fakeObj  then
			game.GetGameWorld():destroyGameObject(fakeObj)
		end
		
	else
		print("Where'd options go?")
	end
	
	game.killCoroutine("VenueSelect")
	
	game.loadMenu("main_menu")
end

VenueSelect.show()
waitForMessage()